#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
日志分析器模块 - ColorBridge
自动检测和分类错误，提供智能诊断和修复建议
"""

import re
import time
from typing import Dict, List, Optional, Tuple, Any
from dataclasses import dataclass, field
from enum import Enum
from collections import defaultdict, deque
import threading
from PyQt6.QtCore import QObject, pyqtSignal


class ErrorSeverity(Enum):
    """错误严重程度"""
    LOW = "low"
    MEDIUM = "medium"
    HIGH = "high"
    CRITICAL = "critical"


class ErrorCategory(Enum):
    """错误类别"""
    SERIAL_CONNECTION = "serial_connection"
    MESSAGE_PROCESSING = "message_processing"
    BUFFER_MANAGEMENT = "buffer_management"
    PERFORMANCE = "performance"
    SYSTEM = "system"
    UNKNOWN = "unknown"


@dataclass
class ErrorEvent:
    """错误事件"""
    timestamp: float
    severity: ErrorSeverity
    category: ErrorCategory
    message: str
    context: Dict[str, Any] = field(default_factory=dict)
    count: int = 1
    first_occurrence: float = field(init=False)
    
    def __post_init__(self):
        self.first_occurrence = self.timestamp


@dataclass
class LogAnalysis:
    """日志分析结果"""
    total_errors: int = 0
    error_counts: Dict[ErrorCategory, int] = field(default_factory=lambda: defaultdict(int))
    severity_counts: Dict[ErrorSeverity, int] = field(default_factory=lambda: defaultdict(int))
    recent_errors: List[ErrorEvent] = field(default_factory=list)
    patterns: List[str] = field(default_factory=list)
    recommendations: List[str] = field(default_factory=list)


class LogPatternMatcher:
    """日志模式匹配器"""
    
    def __init__(self):
        # 定义错误模式
        self.error_patterns = {
            ErrorCategory.SERIAL_CONNECTION: [
                (r'SerialPortError\.(\w+)', ErrorSeverity.HIGH),
                (r'串口连接失败', ErrorSeverity.HIGH),
                # 只有在非正常关闭时的"串口已断开"才报错
                (r'串口已断开.*(?:错误|异常|失败)', ErrorSeverity.MEDIUM),
                (r'串口对象已被删除', ErrorSeverity.MEDIUM),
                (r'重试中.*\(\d+/\d+\)', ErrorSeverity.MEDIUM)
            ],
            
            ErrorCategory.MESSAGE_PROCESSING: [
                (r'消息处理错误.*(?:mdu32|tfpu)', ErrorSeverity.LOW),  # 测试命令错误降级
                (r'消息处理错误', ErrorSeverity.MEDIUM),  # 其他消息处理错误降级
                (r'响应数据处理错误', ErrorSeverity.MEDIUM),
                (r'过滤重复.*', ErrorSeverity.LOW)
                # 移除"检测到.*命令"和"消息处理完成"的误报匹配
            ],
            
            ErrorCategory.BUFFER_MANAGEMENT: [
                (r'缓冲区溢出', ErrorSeverity.HIGH),
                (r'清理超时的部分消息', ErrorSeverity.MEDIUM),
                (r'清理片段过多的部分消息', ErrorSeverity.MEDIUM),
                (r'智能清理缓冲区', ErrorSeverity.MEDIUM),
                (r'缓冲策略配置', ErrorSeverity.LOW)
            ],
            
            ErrorCategory.PERFORMANCE: [
                (r'数据过长.*字符', ErrorSeverity.MEDIUM),
                # 降低性能测试数据的误报 - 只有在明确包含"错误"、"失败"、"异常"时才报错
                (r'平均每次.*时钟周期.*(?:错误|失败|异常|error|fail|exception)', ErrorSeverity.MEDIUM)
                # 移除"性能统计.*bytes/s.*msg/s"和"接收速率.*bytes/s"的误报匹配
            ],
            
            ErrorCategory.SYSTEM: [
                # 移除所有系统日志的误报匹配，只保留真正的错误
                # 系统启动和正常操作日志不应该被标记为错误
            ]
        }
        
        # 定义问题模式
        self.problem_patterns = {
            'infinite_recursion': [
                r'重复.*重复.*重复',
                r'(过滤重复.*响应.*){3,}',
                r'(接收数据.*\.\.\.){10,}'
            ],
            'message_storm': [
                r'(接收数据.*\.\.\.){20,}',
                r'DEBUG.*接收数据.*DEBUG.*接收数据'
            ],
            'connection_instability': [
                r'(串口连接失败.*重试中){2,}',
                r'(串口连接成功.*串口已断开){2,}'
            ],
            'buffer_overflow': [
                r'(缓冲区溢出.*智能清理缓冲区){2,}',
                r'缓冲区大小.*\d+.*bytes'
            ]
        }
    
    def match_error(self, log_line: str) -> Optional[Tuple[ErrorCategory, ErrorSeverity]]:
        """匹配错误模式（带白名单保护）"""
        # 白名单：这些是正常的调试信息，不应该被标记为错误
        whitelist_patterns = [
            r'串口接收到原始数据',
            r'解析设备信息',
            r'DeviceInfoManager.*解析',
            r'SerialReaderThread.*串口接收到',
            r'DEBUG.*ColorBridge.*\[SerialReaderThread\]',
            r'DEBUG.*ColorBridge.*\[DeviceInfoManager\]',
            r'启动修复版本的串口读取线程',
            r'串口读取线程已结束',
            r'性能统计',
            r'接收速率',
            r'bytes/s',
            r'msg/s',
            r'检测到.*命令',
            r'消息处理完成',
            r'AutoInstaller',
            r'环境检测通过',
            r'启动.*窗口',
            r'发现串口'
        ]
        
        # 检查是否在白名单中
        for pattern in whitelist_patterns:
            if re.search(pattern, log_line, re.IGNORECASE):
                return None
        
        # 匹配错误模式
        for category, patterns in self.error_patterns.items():
            for pattern, severity in patterns:
                if re.search(pattern, log_line, re.IGNORECASE):
                    return category, severity
        return None
    
    def detect_problem_pattern(self, log_lines: List[str]) -> List[str]:
        """检测问题模式"""
        detected_patterns = []
        full_log = '\n'.join(log_lines)
        
        for pattern_name, patterns in self.problem_patterns.items():
            for pattern in patterns:
                if re.search(pattern, full_log, re.IGNORECASE | re.MULTILINE):
                    detected_patterns.append(pattern_name)
                    break
        
        return detected_patterns


class ErrorAnalyzer:
    """错误分析器"""
    
    def __init__(self):
        self.error_history = deque(maxlen=1000)  # 保留最近1000个错误
        self.error_frequency = defaultdict(lambda: defaultdict(int))
        self.last_analysis_time = time.time()
        
    def analyze_error(self, error: ErrorEvent) -> Dict[str, Any]:
        """分析单个错误"""
        current_time = time.time()
        
        # 更新错误历史
        self.error_history.append(error)
        
        # 更新频率统计
        time_window = int((current_time // 60))  # 按分钟分组
        self.error_frequency[time_window][error.category] += 1
        
        # 检测错误趋势
        trend_analysis = self._analyze_trends()
        
        # 生成建议
        recommendations = self._generate_recommendations(error, trend_analysis)
        
        return {
            'trend_analysis': trend_analysis,
            'recommendations': recommendations,
            'error_frequency': dict(self.error_frequency[time_window])
        }
    
    def _analyze_trends(self) -> Dict[str, Any]:
        """分析错误趋势"""
        current_time = time.time()
        current_window = int((current_time // 60))
        
        # 统计最近5分钟的错误
        recent_counts = defaultdict(int)
        for i in range(5):
            window = current_window - i
            for category, count in self.error_frequency[window].items():
                recent_counts[category] += count
        
        # 检测上升趋势
        trends = {}
        for category in ErrorCategory:
            if category == ErrorCategory.UNKNOWN:
                continue
                
            recent_count = recent_counts[category]
            if recent_count > 10:
                trends[category] = "high_frequency"
            elif recent_count > 5:
                trends[category] = "medium_frequency"
            elif recent_count > 0:
                trends[category] = "low_frequency"
            else:
                trends[category] = "no_recent_errors"
        
        return trends
    
    def _generate_recommendations(self, error: ErrorEvent, trends: Dict[str, Any]) -> List[str]:
        """生成修复建议"""
        recommendations = []
        
        # 基于错误类别的建议
        if error.category == ErrorCategory.SERIAL_CONNECTION:
            if "重试" in error.message:
                recommendations.append("检查串口连接稳定性，考虑增加重试间隔")
                recommendations.append("验证串口驱动程序是否正常工作")
            else:
                recommendations.append("检查串口权限和设备连接状态")
                recommendations.append("确认设备是否被其他程序占用")
        
        elif error.category == ErrorCategory.MESSAGE_PROCESSING:
            if "重复" in error.message:
                recommendations.append("优化消息去重算法，调整去重窗口时间")
                recommendations.append("检查消息处理器是否陷入循环")
            else:
                recommendations.append("增强消息处理异常处理机制")
                recommendations.append("添加消息处理超时保护")
        
        elif error.category == ErrorCategory.BUFFER_MANAGEMENT:
            recommendations.append("调整缓冲区大小配置")
            recommendations.append("优化缓冲区清理策略")
            recommendations.append("考虑实现分块处理机制")
        
        elif error.category == ErrorCategory.PERFORMANCE:
            # 优化性能错误检测，减少误报
            if "DEBUG" in error.message and "串口接收到原始数据" in error.message:
                # 这是正常的调试信息，不是性能问题
                recommendations.append("调试信息显示正常，无需处理")
            else:
                recommendations.append("监控性能指标，优化处理算法")
                recommendations.append("考虑实现异步处理机制")
        
        # 基于趋势的建议
        for category, trend in trends.items():
            if trend == "high_frequency":
                if category == ErrorCategory.SERIAL_CONNECTION:
                    recommendations.append("串口连接问题频发，建议检查硬件连接")
                elif category == ErrorCategory.MESSAGE_PROCESSING:
                    recommendations.append("消息处理问题频发，建议检查处理逻辑")
        
        return recommendations


class LogAnalyzer(QObject):
    """日志分析器主类"""
    
    # 信号定义
    error_detected = pyqtSignal(ErrorEvent)
    analysis_completed = pyqtSignal(LogAnalysis)
    recommendation_generated = pyqtSignal(list)
    
    def __init__(self, debug_mode: bool = False):
        super().__init__()
        self.debug_mode = debug_mode
        self.pattern_matcher = LogPatternMatcher()
        self.error_analyzer = ErrorAnalyzer()
        
        # 实时分析状态
        self.is_analyzing = False
        self.analysis_thread = None
        self.log_buffer = deque(maxlen=500)  # 保留最近500行日志
        
        # 分析配置
        self.analysis_interval = 30  # 30秒分析一次
        self.error_threshold = 5  # 5个同类错误触发警告
        
        # 统计信息
        self.total_lines_processed = 0
        self.total_errors_detected = 0
        self.start_time = time.time()
    
    def add_log_line(self, log_line: str):
        """添加日志行进行分析"""
        if not log_line or not log_line.strip():
            return
        
        self.total_lines_processed += 1
        self.log_buffer.append(log_line)
        
        # 实时错误检测
        error_info = self.pattern_matcher.match_error(log_line)
        if error_info:
            category, severity = error_info
            
            # 创建错误事件
            error_event = ErrorEvent(
                timestamp=time.time(),
                severity=severity,
                category=category,
                message=log_line.strip(),
                context={'line_number': self.total_lines_processed}
            )
            
            # 检查是否为重复错误
            self._check_duplicate_error(error_event)
            
            # 发出错误检测信号
            self.error_detected.emit(error_event)
            
            # 分析错误
            analysis = self.error_analyzer.analyze_error(error_event)
            
            # 发出建议信号
            if analysis['recommendations']:
                self.recommendation_generated.emit(analysis['recommendations'])
            
            self.total_errors_detected += 1
            
            if self.debug_mode:
                print(f"[DEBUG] 检测到错误: {category.value} - {severity.value}")
                print(f"[DEBUG] 错误消息: {log_line.strip()[:100]}...")
    
    def _check_duplicate_error(self, error: ErrorEvent):
        """检查重复错误并更新计数"""
        # 查找最近的相似错误
        for recent_error in list(self.error_analyzer.error_history)[-10:]:
            if (recent_error.category == error.category and 
                recent_error.severity == error.severity and
                abs(recent_error.timestamp - error.timestamp) < 5.0):  # 5秒内
                
                # 检查消息相似度
                if self._calculate_similarity(recent_error.message, error.message) > 0.8:
                    error.count = recent_error.count + 1
                    error.first_occurrence = recent_error.first_occurrence
                    break
    
    def _calculate_similarity(self, text1: str, text2: str) -> float:
        """计算文本相似度"""
        # 简单的相似度计算
        words1 = set(text1.lower().split())
        words2 = set(text2.lower().split())
        
        if not words1 or not words2:
            return 0.0
        
        intersection = words1.intersection(words2)
        union = words1.union(words2)
        
        return len(intersection) / len(union)
    
    def start_realtime_analysis(self):
        """启动实时分析"""
        if self.is_analyzing:
            return
        
        self.is_analyzing = True
        self.analysis_thread = threading.Thread(target=self._analysis_loop, daemon=True)
        self.analysis_thread.start()
        
        if self.debug_mode:
            print("[DEBUG] 启动实时日志分析")
    
    def stop_realtime_analysis(self):
        """停止实时分析（修复卡死问题）"""
        self.is_analyzing = False
        if self.analysis_thread:
            # 不等待线程完成，直接设置daemon=True让程序退出时自动清理
            # 这样可以避免程序关闭时因等待分析线程而卡死
            try:
                if self.analysis_thread.is_alive():
                    # 只等待很短时间，不阻塞程序关闭
                    self.analysis_thread.join(timeout=0.1)
            except Exception as e:
                if self.debug_mode:
                    print(f"[DEBUG] 停止分析线程失败: {e}")
        
        if self.debug_mode:
            print("[DEBUG] 停止实时日志分析")
    
    def _analysis_loop(self):
        """分析循环"""
        while self.is_analyzing:
            try:
                # 执行周期性分析
                analysis = self.perform_analysis()
                
                if analysis.total_errors > 0:
                    self.analysis_completed.emit(analysis)
                
                # 等待下次分析
                time.sleep(self.analysis_interval)
                
            except Exception as e:
                if self.debug_mode:
                    print(f"[DEBUG] 分析循环错误: {e}")
                time.sleep(5)  # 错误后等待5秒
    
    def perform_analysis(self) -> LogAnalysis:
        """执行完整的日志分析"""
        analysis = LogAnalysis()
        
        # 获取最近的日志行
        recent_logs = list(self.log_buffer)
        
        # 检测问题模式
        analysis.patterns = self.pattern_matcher.detect_problem_pattern(recent_logs)
        
        # 统计错误信息
        for error in self.error_analyzer.error_history:
            analysis.error_counts[error.category] += error.count
            analysis.severity_counts[error.severity] += error.count
            analysis.total_errors += error.count
        
        # 获取最近的错误
        analysis.recent_errors = list(self.error_analyzer.error_history)[-10:]
        
        # 生成综合建议
        analysis.recommendations = self._generate_comprehensive_recommendations(analysis)
        
        return analysis
    
    def _generate_comprehensive_recommendations(self, analysis: LogAnalysis) -> List[str]:
        """生成综合修复建议"""
        recommendations = []
        
        # 基于错误总数的建议
        if analysis.total_errors > 50:
            recommendations.append("错误数量过多，建议立即检查系统状态")
        elif analysis.total_errors > 20:
            recommendations.append("错误数量较多，建议关注系统稳定性")
        
        # 基于错误类别的建议
        for category, count in analysis.error_counts.items():
            if count > 10:
                if category == ErrorCategory.SERIAL_CONNECTION:
                    recommendations.append("串口连接问题严重，建议检查硬件和驱动")
                elif category == ErrorCategory.MESSAGE_PROCESSING:
                    recommendations.append("消息处理问题频发，建议优化处理逻辑")
                elif category == ErrorCategory.BUFFER_MANAGEMENT:
                    recommendations.append("缓冲区管理问题，建议调整配置参数")
        
        # 基于问题模式的建议
        if 'infinite_recursion' in analysis.patterns:
            recommendations.append("检测到无限递归模式，建议添加递归深度限制")
        
        if 'message_storm' in analysis.patterns:
            recommendations.append("检测到消息风暴，建议实现流量控制机制")
        
        if 'connection_instability' in analysis.patterns:
            recommendations.append("检测到连接不稳定，建议增强重连机制")
        
        if 'buffer_overflow' in analysis.patterns:
            recommendations.append("检测到缓冲区溢出，建议优化内存管理")
        
        return recommendations
    
    def get_statistics(self) -> Dict[str, Any]:
        """获取统计信息"""
        elapsed_time = time.time() - self.start_time
        
        return {
            'total_lines_processed': self.total_lines_processed,
            'total_errors_detected': self.total_errors_detected,
            'analysis_runtime': elapsed_time,
            'lines_per_second': self.total_lines_processed / elapsed_time if elapsed_time > 0 else 0,
            'errors_per_minute': (self.total_errors_detected / elapsed_time) * 60 if elapsed_time > 0 else 0,
            'buffer_size': len(self.log_buffer),
            'is_analyzing': self.is_analyzing
        }
    
    def export_analysis_report(self, filename: str = None) -> str:
        """导出分析报告"""
        if not filename:
            timestamp = time.strftime("%Y%m%d_%H%M%S")
            filename = f"colorbridge_log_analysis_{timestamp}.txt"
        
        analysis = self.perform_analysis()
        stats = self.get_statistics()
        
        report = f"""
ColorBridge 日志分析报告
========================

生成时间: {time.strftime('%Y-%m-%d %H:%M:%S')}

统计信息:
- 总处理行数: {stats['total_lines_processed']}
- 总检测错误: {stats['total_errors_detected']}
- 分析运行时间: {stats['analysis_runtime']:.2f}秒
- 处理速度: {stats['lines_per_second']:.2f}行/秒
- 错误频率: {stats['errors_per_minute']:.2f}错误/分钟

错误统计:
"""
        
        for category, count in analysis.error_counts.items():
            report += f"- {category.value}: {count}次\n"
        
        report += "\n严重程度统计:\n"
        for severity, count in analysis.severity_counts.items():
            report += f"- {severity.value}: {count}次\n"
        
        if analysis.patterns:
            report += "\n检测到的问题模式:\n"
            for pattern in analysis.patterns:
                report += f"- {pattern}\n"
        
        if analysis.recommendations:
            report += "\n修复建议:\n"
            for i, rec in enumerate(analysis.recommendations, 1):
                report += f"{i}. {rec}\n"
        
        if analysis.recent_errors:
            report += "\n最近的错误事件:\n"
            for error in analysis.recent_errors[-5:]:  # 只显示最近5个
                report += f"- [{error.severity.value}] {error.category.value}: {error.message[:80]}...\n"
        
        try:
            with open(filename, 'w', encoding='utf-8') as f:
                f.write(report)
            
            if self.debug_mode:
                print(f"[DEBUG] 分析报告已导出: {filename}")
            
            return filename
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 导出报告失败: {e}")
            return None


"""
台球游戏核心逻辑模块
实现2D模仿3D的台球物理引擎
"""

import math
import random
from typing import List, Tuple, Optional
from dataclasses import dataclass
from enum import Enum


class BallType(Enum):
    """台球类型"""
    CUE = "cue"      # 母球
    SOLID = "solid"  # 实心球
    STRIPE = "stripe"  # 条纹球
    BLACK = "black"  # 黑8


@dataclass
class Ball:
    """台球类"""
    x: float
    y: float
    radius: float
    ball_type: BallType
    number: int = 0
    vx: float = 0.0
    vy: float = 0.0
    mass: float = 1.0
    friction: float = 0.98
    is_pocketed: bool = False
    
    def update(self, dt: float):
        """更新球的位置"""
        if self.is_pocketed:
            return
            
        # 应用速度
        self.x += self.vx * dt
        self.y += self.vy * dt
        
        # 应用摩擦力
        self.vx *= self.friction
        self.vy *= self.friction
        
        # 速度过小时停止
        if abs(self.vx) < 0.1:
            self.vx = 0
        if abs(self.vy) < 0.1:
            self.vy = 0
    
    def apply_force(self, fx: float, fy: float):
        """应用力"""
        self.vx += fx / self.mass
        self.vy += fy / self.mass
    
    def distance_to(self, other: 'Ball') -> float:
        """计算到另一个球的距离"""
        return math.sqrt((self.x - other.x)**2 + (self.y - other.y)**2)
    
    def collides_with(self, other: 'Ball') -> bool:
        """检测是否与另一个球碰撞"""
        if self.is_pocketed or other.is_pocketed:
            return False
        return self.distance_to(other) < (self.radius + other.radius)
    
    def resolve_collision(self, other: 'Ball'):
        """解析球与球的碰撞"""
        if not self.collides_with(other):
            return
            
        # 计算碰撞法向量
        dx = other.x - self.x
        dy = other.y - self.y
        distance = math.sqrt(dx*dx + dy*dy)
        
        if distance == 0:
            return
            
        nx = dx / distance
        ny = dy / distance
        
        # 计算相对速度
        dvx = other.vx - self.vx
        dvy = other.vy - self.vy
        
        # 计算相对速度在法向量上的投影
        dvn = dvx * nx + dvy * ny
        
        # 如果球正在分离，不处理碰撞
        if dvn > 0:
            return
            
        # 计算冲量
        impulse = 2 * dvn / (self.mass + other.mass)
        
        # 应用冲量
        self.vx += impulse * other.mass * nx
        self.vy += impulse * other.mass * ny
        other.vx -= impulse * self.mass * nx
        other.vy -= impulse * self.mass * ny
        
        # 防止球重叠
        overlap = (self.radius + other.radius) - distance
        if overlap > 0:
            self.x -= overlap * nx * 0.5
            self.y -= overlap * ny * 0.5
            other.x += overlap * nx * 0.5
            other.y += overlap * ny * 0.5


class Table:
    """台球桌类"""
    def __init__(self, width: float = 800, height: float = 400):
        self.width = width
        self.height = height
        self.cushion_width = 20
        self.pocket_radius = 25
        
        # 定义球袋位置
        self.pockets = [
            (self.cushion_width, self.cushion_width),  # 左上
            (self.width // 2, self.cushion_width),     # 上中
            (self.width - self.cushion_width, self.cushion_width),  # 右上
            (self.cushion_width, self.height - self.cushion_width),  # 左下
            (self.width // 2, self.height - self.cushion_width),    # 下中
            (self.width - self.cushion_width, self.height - self.cushion_width)  # 右下
        ]
    
    def check_pocket(self, ball: Ball) -> bool:
        """检查球是否进袋"""
        if ball.is_pocketed:
            return True
            
        for px, py in self.pockets:
            distance = math.sqrt((ball.x - px)**2 + (ball.y - py)**2)
            if distance < self.pocket_radius:
                ball.is_pocketed = True
                ball.vx = 0
                ball.vy = 0
                # 将球移动到屏幕外，避免卡在洞口
                ball.x = -100
                ball.y = -100
                return True
        return False
    
    def check_wall_collision(self, ball: Ball):
        """检查球与桌边的碰撞"""
        if ball.is_pocketed:
            return
            
        # 左墙
        if ball.x - ball.radius < self.cushion_width:
            ball.x = self.cushion_width + ball.radius
            ball.vx = -ball.vx * 0.9
            
        # 右墙
        if ball.x + ball.radius > self.width - self.cushion_width:
            ball.x = self.width - self.cushion_width - ball.radius
            ball.vx = -ball.vx * 0.9
            
        # 上墙
        if ball.y - ball.radius < self.cushion_width:
            ball.y = self.cushion_width + ball.radius
            ball.vy = -ball.vy * 0.9
            
        # 下墙
        if ball.y + ball.radius > self.height - self.cushion_width:
            ball.y = self.height - self.cushion_width - ball.radius
            ball.vy = -ball.vy * 0.9


class BilliardGame:
    """台球游戏主类"""
    def __init__(self):
        self.table = Table()
        self.balls: List[Ball] = []
        self.cue_ball: Optional[Ball] = None
        self.game_state = "setup"  # setup, aiming, shooting, moving, game_over
        self.shot_power = 0.0
        self.max_power = 300.0  # 最大力气值提高到300%
        self.player_score = 0  # 单人游戏，只有一个分数
        self.game_type = "8ball"  # 8球规则
        self.new_pocketed_balls: List[Ball] = []  # 本次回合新进袋的球
        
        self.setup_game()
    
    def setup_game(self):
        """设置游戏初始状态"""
        self.balls.clear()
        
        # 创建母球
        self.cue_ball = Ball(
            x=self.table.width * 0.25,
            y=self.table.height // 2,
            radius=12,
            ball_type=BallType.CUE,
            number=0
        )
        self.balls.append(self.cue_ball)
        
        # 创建目标球（三角形排列）
        ball_radius = 11
        positions = self._create_triangle_formation(
            self.table.width * 0.75,
            self.table.height // 2,
            ball_radius
        )
        
        # 分配球类型
        ball_numbers = list(range(1, 16))
        random.shuffle(ball_numbers)
        
        for i, (x, y) in enumerate(positions):
            if i == 4:  # 顶点球
                ball_type = BallType.BLACK
                number = 8
            elif i % 2 == 0:
                ball_type = BallType.SOLID
                number = ball_numbers.pop()
            else:
                ball_type = BallType.STRIPE
                number = ball_numbers.pop()
                
            ball = Ball(
                x=x, y=y,
                radius=ball_radius,
                ball_type=ball_type,
                number=number
            )
            self.balls.append(ball)
        
        self.game_state = "aiming"
        self.shot_power = 0.0
    
    def _create_triangle_formation(self, center_x: float, center_y: float, radius: float) -> List[Tuple[float, float]]:
        """创建三角形排列"""
        positions = []
        row_count = 5
        
        for row in range(row_count):
            balls_in_row = row + 1
            start_x = center_x - (balls_in_row - 1) * radius * 2 * 0.866  # 水平间距
            for col in range(balls_in_row):
                x = start_x + col * radius * 2 * 0.866 * 2
                y = center_y - (row_count - row - 1) * radius * 2
                positions.append((x, y))
        
        return positions
    
    def update(self, dt: float):
        """更新游戏状态"""
        if self.game_state != "moving":
            return
            
        # 更新所有球
        for ball in self.balls:
            # 保存进袋状态
            was_pocketed = ball.is_pocketed
            
            ball.update(dt)
            
            # 检查球袋
            if self.table.check_pocket(ball):
                # 如果是新进袋的球，添加到列表
                if not was_pocketed:
                    self.new_pocketed_balls.append(ball)
            
            # 检查墙壁碰撞
            self.table.check_wall_collision(ball)
        
        # 检查球与球之间的碰撞
        for i in range(len(self.balls)):
            for j in range(i + 1, len(self.balls)):
                if self.balls[i].collides_with(self.balls[j]):
                    self.balls[i].resolve_collision(self.balls[j])
        
        # 检查是否所有球都停止
        if self._all_balls_stopped():
            self._end_turn()
    
    def _all_balls_stopped(self) -> bool:
        """检查是否所有球都停止运动"""
        for ball in self.balls:
            if not ball.is_pocketed and (abs(ball.vx) > 0.1 or abs(ball.vy) > 0.1):
                return False
        return True
    
    def aim_shot(self, angle: float):
        """瞄准击球"""
        if self.game_state != "aiming" or self.cue_ball.is_pocketed:
            return
            
        self.shot_angle = angle
    
    def charge_power(self, power: float):
        """蓄力"""
        if self.game_state != "aiming":
            return
            
        self.shot_power = min(power, self.max_power)
    
    def take_shot(self):
        """击球"""
        if self.game_state != "aiming" or self.cue_ball.is_pocketed:
            return
            
        # 计算击球力（增加力量乘数，让球飞得更远）
        power_multiplier = 10.0  # 增加10倍力量
        force_x = math.cos(self.shot_angle) * self.shot_power * power_multiplier
        force_y = math.sin(self.shot_angle) * self.shot_power * power_multiplier
        
        # 应用力到母球
        self.cue_ball.apply_force(force_x, force_y)
        
        # 更新游戏状态
        self.game_state = "moving"
        self.shot_power = 0.0
        # 重置新进袋球列表
        self.new_pocketed_balls.clear()
    
    def _end_turn(self):
        """结束当前回合"""
        # 使用本次回合新进袋的球
        pocketed_balls = self.new_pocketed_balls
        
        # 更新分数（单人游戏，所有进袋球都加分）
        for ball in pocketed_balls:
            if ball.ball_type != BallType.CUE:  # 母球进袋不加分
                self.player_score += 1
        
        # 检查黑8是否进袋
        for ball in pocketed_balls:
            if ball.ball_type == BallType.BLACK:
                # 黑8进袋，游戏结束
                self._end_game()
                return
        
        # 单人游戏，不切换玩家，直接回到瞄准状态
        self.game_state = "aiming"
        
        # 如果母球进袋，重置位置
        if self.cue_ball.is_pocketed:
            # 调试信息：母球重置
            print(f"[DEBUG] 母球进袋，重置位置到 ({self.table.width * 0.25:.1f}, {self.table.height // 2:.1f})")
            self.cue_ball.is_pocketed = False
            self.cue_ball.x = self.table.width * 0.25
            self.cue_ball.y = self.table.height // 2
            self.cue_ball.vx = 0
            self.cue_ball.vy = 0
    
    def _check_black_8_valid(self) -> bool:
        """检查黑8是否合法进袋（单人游戏简化版）"""
        # 单人游戏：只要黑8进袋就有效
        return True
    
    def _end_game(self):
        """结束游戏"""
        self.game_state = "game_over"
        self.winner = f"玩家 (得分: {self.player_score})"
    
    def reset_game(self):
        """重置游戏"""
        self.setup_game()
        self.player_score = 0
        self.game_state = "aiming"
        self.new_pocketed_balls.clear()


"""
ColorBridge 主入口模块
作为colorbridge包的__main__模块，提供命令行入口点
"""

import sys
import os

# 添加包目录到路径，确保可以导入同级模块
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

def main():
    """主函数 - 启动增强稳定版本的ColorBridge"""
    # 解析命令行参数
    debug_mode = "--debug" in sys.argv or "-d" in sys.argv
    quiet_mode = "--quiet" in sys.argv or "-q" in sys.argv
    version_mode = "--version" in sys.argv or "-v" in sys.argv
    help_mode = "--help" in sys.argv or "-h" in sys.argv
    
    # 显示版本信息
    if version_mode:
        print("ColorBridge v2.1.10 - AI8051U串口助手")
        print("作者: 076lik")
        print("许可证: GPLv3")
        return 0
    
    # 显示帮助信息
    if help_mode:
        print("ColorBridge - AI8051U串口助手")
        print("")
        print("用法: colorbridge [选项]")
        print("")
        print("选项:")
        print("  -d, --debug    启用调试模式，显示详细调试信息")
        print("  -q, --quiet    静默模式，只显示错误信息")
        print("  -v, --version  显示版本信息")
        print("  -h, --help     显示此帮助信息")
        print("")
        print("示例:")
        print("  colorbridge              # 正常启动")
        print("  colorbridge --debug      # 调试模式启动")
        print("  colorbridge --quiet      # 静默模式启动")
        return 0
    
    # 导入必要的模块
    try:
        from PyQt6.QtWidgets import QApplication
        from PyQt6.QtCore import Qt
    except ImportError as e:
        print(f"❌ 缺少PyQt6依赖: {e}")
        print("请安装依赖: pip install PyQt6")
        return 1
    
    # 创建 QApplication 实例
    app = QApplication(sys.argv)
    app.setApplicationName("ColorBridge")
    app.setApplicationVersion("2.1.10")
    app.setOrganizationName("076lik")
    
    # 设置应用程序样式
    app.setStyle("Fusion")
    
    # 显示启动模式
    if debug_mode:
        print("🐛 ColorBridge 调试模式启动")
    elif quiet_mode:
        print("🤫 ColorBridge 静默模式启动")
    else:
        print("🌈 ColorBridge 正常模式启动")
    
    # 确保logs目录存在
    from pathlib import Path
    logs_dir = Path("logs")
    logs_dir.mkdir(parents=True, exist_ok=True)
    
    # 初始化日志管理器、保护器和监控系统
    logger_manager = None
    log_protector = None
    monitoring_system = None
    log_analyzer = None
    
    try:
        # 初始化日志管理器（先初始化，这样保护器就知道当前日志文件）
        try:
            from core.colorbridge_logger_manager import init_logger_manager
            logger_manager = init_logger_manager(debug_mode=debug_mode)  # 使用用户指定的调试模式
            logger_manager.log_system_event("SYSTEM", "ColorBridge 启动中...")
        except ImportError as e:
            print(f"❌ 无法导入日志管理器: {e}")
            return 1
        
        # 初始化日志保护器（在日志管理器之后初始化，避免保护当前文件）
        try:
            from core.colorbridge_log_protector import init_log_protector
            log_protector = init_log_protector()
            if logger_manager:
                logger_manager.log_system_event("SYSTEM", "日志保护已启用")
        except ImportError as e:
            print(f"⚠️ 无法导入日志保护器: {e}")
        
        # 初始化监控系统
        try:
            from core.colorbridge_monitoring_system import MonitoringSystem
            monitoring_system = MonitoringSystem(debug_mode=debug_mode)
            if logger_manager:
                logger_manager.log_system_event("SYSTEM", "监控系统已启动")
        except ImportError as e:
            print(f"⚠️ 无法导入监控系统: {e}")
        
        # 初始化日志分析器
        try:
            from core.colorbridge_log_analyzer import LogAnalyzer
            log_analyzer = LogAnalyzer(debug_mode=debug_mode)
        except ImportError as e:
            if debug_mode:
                print(f"⚠️ 无法导入日志分析器: {e}")
        
        # 创建主窗口
        try:
            from ui.colorbridge_main_window import ColorBridgeMainWindow
            
            # 创建主窗口实例
            main_window = ColorBridgeMainWindow(
                logger_manager=logger_manager,
                log_protector=log_protector,
                monitoring_system=monitoring_system,
                log_analyzer=log_analyzer
            )
            
            # 显示主窗口
            main_window.show()
            
            # 记录启动完成
            if logger_manager:
                logger_manager.log_system_event("SYSTEM", "ColorBridge 启动完成")
            
            # 运行应用程序
            return app.exec()
            
        except ImportError as e:
            print(f"❌ 无法导入主窗口模块: {e}")
            return 1
        except Exception as e:
            print(f"❌ 启动过程中发生异常: {e}")
            if debug_mode:
                import traceback
                traceback.print_exc()
            return 1
            
    except Exception as e:
        print(f"❌ 系统初始化失败: {e}")
        if debug_mode:
            import traceback
            traceback.print_exc()
        return 1


if __name__ == "__main__":
    sys.exit(main())


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
设备信息管理器模块 - ColorBridge
收集、解析和管理AI8051U设备系统信息
"""

import re
import time
import hashlib
import json
from typing import Dict, List, Optional
from datetime import datetime
from PyQt6.QtCore import QObject, pyqtSignal
from copy import deepcopy

# 导入日志相关模块
from .colorbridge_debug_logger import get_debug_logger, debug_log, info_log, warning_log, error_log

class LogLevel:
    DEBUG = 0
    INFO = 1
    WARNING = 2
    ERROR = 3
    CRITICAL = 4

class DebugLogger:
    """简化的日志级别控制"""
    def __init__(self, level=LogLevel.INFO):
        self.level = level
    
    def debug(self, message):
        if self.level <= LogLevel.DEBUG:
            debug_log(message, "DeviceInfoManager")
    
    def info(self, message):
        if self.level <= LogLevel.INFO:
            info_log(message, "DeviceInfoManager")
    
    def warning(self, message):
        if self.level <= LogLevel.WARNING:
            warning_log(message, "DeviceInfoManager")
    
    def error(self, message):
        if self.level <= LogLevel.ERROR:
            error_log(message, "DeviceInfoManager")

class SafeDeviceInfoParser:
    """安全的设备信息解析器"""
    
    def __init__(self, debug_mode: bool = False):
        self.debug_mode = debug_mode
        self.parse_cache = {}
        self.parse_failures = 0
        self.max_failures = 5
    
    def safe_parse_device_info(self, data: str) -> dict:
        """安全解析设备信息"""
        try:
            # 检查缓存
            data_hash = hash(data)
            if data_hash in self.parse_cache:
                return self.parse_cache[data_hash]
            
            # 安全解析
            parsed_info = self._parse_with_fallback(data)
            
            # 成功解析，重置失败计数
            self.parse_failures = 0
            
            # 缓存结果
            self.parse_cache[data_hash] = parsed_info
            
            return parsed_info
            
        except Exception as e:
            self.parse_failures += 1
            
            if self.debug_mode:
                debug_log(f"设备信息解析失败 ({self.parse_failures}/{self.max_failures}): {e}", "DeviceInfoManager")
            
            # 失败次数过多时，清空缓存重新开始
            if self.parse_failures >= self.max_failures:
                self.parse_cache.clear()
                self.parse_failures = 0
                
                if self.debug_mode:
                    debug_log("设备信息解析失败次数过多，清空缓存", "DeviceInfoManager")
            
            # 返回安全的默认信息
            return self._get_safe_default_info()
    
    def _parse_with_fallback(self, data: str) -> dict:
        """带回退机制的解析"""
        try:
            # 主要解析逻辑
            return self._parse_device_info_primary(data)
        except Exception as e:
            if self.debug_mode:
                debug_log(f"主解析失败，使用回退解析: {e}", "DeviceInfoManager")
            # 回退解析逻辑
            return self._parse_device_info_fallback(data)
    
    def _get_safe_default_info(self) -> dict:
        """获取安全的默认信息"""
        return {
            'status': 'parsing_error',
            'timestamp': time.time(),
            'message': '设备信息解析暂时不可用'
        }
    
    def _direct_parse_message(self, message: str) -> bool:
        """直接解析消息，不依赖正则表达式"""
        updated = False
        
        # 按行处理消息
        lines = message.split('\n')
        for line in lines:
            line = line.strip()
            if not line:
                continue
            
            # 直接匹配关键信息
            if '微控制器:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    mcu = parts[1].strip()
                    self.device_info['system']['mcu'] = mcu
                    if self.debug_mode:
                        debug_log(f"直接解析MCU: {mcu}", "DeviceInfoManager")
                    updated = True
            
            elif '时钟频率:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    freq = parts[1].strip()
                    self.device_info['system']['clock_frequency'] = freq
                    self.device_info['system']['clock'] = freq
                    self.device_info['system']['cpu_clock'] = freq
                    self.device_info['performance']['cpu_frequency'] = freq
                    
                    # 尝试提取TFPU频率
                    if 'TFPU:' in freq or 'tfpu:' in freq.lower():
                        # 简单提取TFPU频率
                        if '(' in freq and ')' in freq:
                            tfpu_part = freq[freq.find('(')+1:freq.find(')')]
                            if 'TFPU:' in tfpu_part:
                                tfpu_freq = tfpu_part.split(':', 1)[1].strip()
                                self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                                self.device_info['performance']['tfpu_enabled'] = True
                    
                    if self.debug_mode:
                        debug_log(f"直接解析时钟频率: {freq}", "DeviceInfoManager")
                    updated = True
            
            elif 'Flash大小:' in line or 'Flash:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    flash = parts[1].strip()
                    self.device_info['system']['flash_size'] = flash
                    self.device_info['system']['flash'] = flash
                    if self.debug_mode:
                        debug_log(f"直接解析Flash: {flash}", "DeviceInfoManager")
                    updated = True
            
            elif 'XRAM大小:' in line or 'XRAM:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    xram = parts[1].strip()
                    self.device_info['system']['xram_size'] = xram
                    self.device_info['system']['xram'] = xram
                    if self.debug_mode:
                        debug_log(f"直接解析XRAM: {xram}", "DeviceInfoManager")
                    updated = True
            
            elif 'USB-CDC:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    usb = parts[1].strip()
                    self.device_info['system']['usb_cdc'] = usb
                    if self.debug_mode:
                        debug_log(f"直接解析USB-CDC: {usb}", "DeviceInfoManager")
                    updated = True
            
            elif 'Flash已用:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    flash_used = parts[1].strip()
                    if 'memory' not in self.device_info:
                        self.device_info['memory'] = {}
                    self.device_info['memory']['flash_used'] = flash_used
                    if self.debug_mode:
                        debug_log(f"直接解析Flash已用: {flash_used}", "DeviceInfoManager")
                    updated = True
            
            elif '内部RAM:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    internal_ram = parts[1].strip()
                    if 'memory' not in self.device_info:
                        self.device_info['memory'] = {}
                    self.device_info['memory']['internal_ram'] = internal_ram
                    if self.debug_mode:
                        debug_log(f"直接解析内部RAM: {internal_ram}", "DeviceInfoManager")
                    updated = True
            
            elif '当前时间:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    rtc_time = parts[1].strip()
                    self.device_info['status']['rtc_time'] = rtc_time
                    if self.debug_mode:
                        debug_log(f"直接解析RTC时间: {rtc_time}", "DeviceInfoManager")
                    updated = True
        
        return updated
    
    def _parse_device_info_primary(self, data: str) -> dict:
        """主要解析逻辑"""
        result = {}
        
        # 解析MCU信息
        mcu_match = re.search(r'微控制器:\s*(.+)', data)
        if mcu_match:
            result['mcu'] = mcu_match.group(1).strip()
        
        # 解析时钟频率
        clock_match = re.search(r'时钟频率:\s*(.+)', data)
        if clock_match:
            result['clock_frequency'] = clock_match.group(1).strip()
        
        # 解析Flash大小
        flash_match = re.search(r'Flash大小:\s*(.+)', data)
        if flash_match:
            result['flash_size'] = flash_match.group(1).strip()
        
        # 解析XRAM大小
        xram_match = re.search(r'XRAM大小:\s*(.+)', data)
        if xram_match:
            result['xram_size'] = xram_match.group(1).strip()
        
        # 解析USB-CDC状态
        usb_match = re.search(r'USB-CDC:\s*(.+)', data)
        if usb_match:
            result['usb_cdc'] = usb_match.group(1).strip()
        
        return result
    
    def _parse_device_info_fallback(self, data: str) -> dict:
        """回退解析逻辑 - 更宽松的解析"""
        result = {}
        
        # 更宽松的MCU解析
        for pattern in [r'MCU[:\s]*(.+)', r'微控制器[:\s]*(.+)', r'控制器[:\s]*(.+)']:
            match = re.search(pattern, data, re.IGNORECASE)
            if match:
                result['mcu'] = match.group(1).strip()
                break
        
        # 更宽松的时钟频率解析
        for pattern in [r'时钟[:\s]*([\d.]+\s*[MG]Hz)', r'频率[:\s]*([\d.]+\s*[MG]Hz)', r'clock[:\s]*([\d.]+\s*[MG]Hz)']:
            match = re.search(pattern, data, re.IGNORECASE)
            if match:
                result['clock_frequency'] = match.group(1).strip()
                break
        
        # 更宽松的Flash解析
        for pattern in [r'Flash[:\s]*([\d.]+\s*[KMGT]?B)', r'闪存[:\s]*([\d.]+\s*[KMGT]?B)']:
            match = re.search(pattern, data, re.IGNORECASE)
            if match:
                result['flash_size'] = match.group(1).strip()
                break
        
        # 更宽松的XRAM解析
        for pattern in [r'XRAM[:\s]*([\d.]+\s*[KMGT]?B)', r'外部RAM[:\s]*([\d.]+\s*[KMGT]?B)']:
            match = re.search(pattern, data, re.IGNORECASE)
            if match:
                result['xram_size'] = match.group(1).strip()
                break
        
        return result


class ColorBridgeDeviceInfoManager(QObject):
    """设备信息管理器 - 清理版本"""
    
    # 信号定义
    device_info_updated = pyqtSignal(dict)
    
    def __init__(self, serial_manager=None):
        super().__init__()
        self.debug_mode = False  # 默认关闭调试模式
        self.logger = DebugLogger(LogLevel.INFO)
        self.logger = DebugLogger(LogLevel.DEBUG if self.debug_mode else LogLevel.INFO)
        
        # 保存串口管理器引用用于连接状态检查
        self.serial_manager = serial_manager
        
        # 初始化安全解析器
        self.safe_parser = SafeDeviceInfoParser(debug_mode=self.debug_mode)
        
        # 设备信息存储
        self.device_info = {
            'system': {
                'mcu': '',
                'clock': '',
                'clock_frequency': '',  # 新增字段
                'flash': '',
                'flash_size': '',  # 新增字段
                'flash_used': '',
                'xram': '',
                'xram_size': '',  # 新增字段
                'xram_used': '',
                'internal_ram': '',
                'usb_cdc': '',
                'compile_date': '',
                'compile_time': '',
                'build_date': '',  # 兼容字段
                'build_time': '',  # 兼容字段
                'rtc_time': '',
                'power_management': '',
                'version': '',  # 版本信息
                'author': '',  # 作者信息
                'system': ''  # 系统名称
            },
            'hardware': {
                'gpio': {
                    'count': '',
                    'type': '',
                    'interrupts': ''
                },
                'timers': {
                    'count': '',
                    'types': '',
                    'pwm_channels': ''
                },
                'uart': {
                    'count': '',
                    'baud_rates': '',
                    'flow_control': ''
                },
                'spi': {
                    'count': '',
                    'max_speed': '',
                    'modes': ''
                },
                'i2c': {
                    'count': '',
                    'max_speed': '',
                    'address_bits': ''
                },
                'adc': {
                    'resolution': '',
                    'channels': '',
                    'reference': ''
                },
                'dac': {
                    'resolution': '',
                    'channels': '',
                    'output_range': ''
                },
                'mdu32': {
                    'status': '',
                    'description': '',
                    'multiply_result': '',
                    'multiply_time': '',
                    'multiply_ratio': '',
                    'divide_result': '',
                    'divide_time': '',
                    'divide_ratio': ''
                },
                'tfpu': {
                    'status': '',
                    'description': '',
                    'add_result': '',
                    'add_time': '',
                    'add_ratio': '',
                    'multiply_result': '',
                    'multiply_time': '',
                    'multiply_ratio': '',
                    'divide_result': '',
                    'divide_time': '',
                    'divide_ratio': '',
                    'sin_result': '',
                    'sin_time': '',
                    'sin_ratio': ''
                }
            },
            'performance': {
                'cpu_frequency': '',
                'instruction_cycle': '',
                'multiply_divide_cycles': '',
                'tfpu_enabled': False,
                'tfpu_frequency': '',
                'benchmark_results': '',
                'memory_usage': '',
                'power_consumption': ''
            },
            'memory': {  # 添加缺失的memory键
                'flash_used': '',
                'flash_constants': '',
                'xram_used': '',
                'internal_ram_used': ''
            },
            'status': {
                'connection_status': '',
                'last_update': datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
                'error_count': 0,
                'warning_count': 0,
                'system_info_mode': False,
                'hardware_test_mode': False,
                'memory_mode': False,
                'voltage_mode': False,
                'clock_info_mode': False,
                'neofetch_mode': False,
                'system_startup_mode': False  # 新增：系统启动信息解析模式
            }
        }
        
        # 解析状态
        self.parsing_mode = None
        self.current_section = None
        
        # 性能监控
        self.last_update_time = time.time()
        self.update_count = 0
        
        # 去重机制 - 避免重复更新，但允许时间戳更新
        self.last_device_info_hash = None
        self.dedup_window = 2.0  # 2秒去重窗口，允许时间戳变化
        self.last_update_time = 0
        self.content_dedup_window = 0.5  # 内容去重窗口（更短，避免重复内容）
        self.last_content_hash = None
        
        # 添加模式超时机制
        self.mode_start_time = {}
        self.mode_timeout = 5  # 5秒超时
        
        # 初始化正则表达式模式
        self._initialize_patterns()
        
    def _update_timestamp(self):
        """更新时间戳"""
        try:
            self.device_info['status']['last_update'] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
        except Exception as e:
            if self.debug_mode:
                debug_log(f"更新时间戳失败: {e}", "DeviceInfoManager")
    
    def _safe_emit_device_info_update(self):
        """安全地发送设备信息更新信号，同时更新时间戳"""
        self._update_timestamp()
        self.device_info_updated.emit(self.device_info)
        
    def _initialize_patterns(self):
        """初始化正则表达式模式"""
        # 编译正则表达式
        self.patterns = {
            'system_info': re.compile(r'系统信息:'),
            'mcu': re.compile(r'微控制器:\s*(.+)'),
            'system_mcu': re.compile(r'ℹ️ 微控制器:\s*(.+)'),  # 新版本格式
            'clock': re.compile(r'时钟频率:\s*(.+)'),
            'system_clock': re.compile(r'ℹ️ 时钟频率:\s*(.+)'),  # 新版本格式
            'flash': re.compile(r'Flash大小:\s*(.+)'),
            'system_flash': re.compile(r'🖥️ Flash:\s*(.+)'),  # 新版本格式
            'xram': re.compile(r'XRAM大小:\s*(.+)'),
            'system_xram': re.compile(r'🖥️ XRAM:\s*(.+)'),  # 新版本格式
            'usb_cdc': re.compile(r'USB-CDC:\s*(.+)'),
            'system_usb_cdc': re.compile(r'✅ USB-CDC:\s*(.+)'),  # 新版本格式
            'build_date': re.compile(r'编译日期:\s*(.+)'),
            'build_time': re.compile(r'编译时间:\s*(.+)'),
            'rtc_time': re.compile(r'当前时间:\s*(.+)'),
            'flash_constants': re.compile(r'常量存储:\s*(.+)'),
            'voltage': re.compile(r'电源电压:\s*(.+)'),
            'voltage_raw': re.compile(r'ADC原始值:\s*(.+)'),
            'voltage_channel': re.compile(r'测量通道:\s*(.+)'),
            'voltage_reference': re.compile(r'参考电压:\s*(.+)'),
            'voltage_resolution': re.compile(r'分辨率:\s*(.+)'),
            'voltage_samples': re.compile(r'采样次数:\s*(.+)'),
            'flash_used': re.compile(r'Flash已用:\s*(.+)'),
            'xram_used': re.compile(r'XRAM已用:\s*(.+)'),
            'internal_ram': re.compile(r'内部RAM:\s*(.+)'),
            'tfpu_clock': re.compile(r'TFPU时钟源:\s*(.+)'),
            'cpu_clock': re.compile(r'CPU时钟:\s*(.+)'),
            'tfpu_clkdiv_reg': re.compile(r'TFPU_CLKDIV寄存器:\s*(.+)'),
            'mdu32_multiply': re.compile(r'乘法测试:\s*(.+)'),
            'mdu32_multiply_time': re.compile(r'执行时间:\s*(.+)'),
            'mdu32_multiply_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'mdu32_divide': re.compile(r'除法测试:\s*(.+)'),
            'mdu32_divide_time': re.compile(r'执行时间:\s*(.+)'),
            'mdu32_divide_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'tfpu_add': re.compile(r'加法测试:\s*(.+)'),
            'tfpu_add_time': re.compile(r'执行时间:\s*(.+)'),
            'tfpu_add_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'tfpu_multiply': re.compile(r'乘法测试:\s*(.+)'),
            'tfpu_multiply_time': re.compile(r'执行时间:\s*(.+)'),
            'tfpu_multiply_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'tfpu_sin': re.compile(r'正弦测试:\s*(.+)'),
            'tfpu_sin_time': re.compile(r'执行时间:\s*(.+)'),
            'tfpu_sin_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'tfpu_cos': re.compile(r'余弦测试:\s*(.+)'),
            'tfpu_cos_time': re.compile(r'执行时间:\s*(.+)'),
            'tfpu_cos_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'tfpu_sqrt': re.compile(r'平方根测试:\s*(.+)'),
            'tfpu_sqrt_time': re.compile(r'执行时间:\s*(.+)'),
            'tfpu_sqrt_ratio': re.compile(r'硬件加速比:\s*(.+)'),
            'hardware_status': re.compile(r'硬件状态:'),
            'neofetch_system': re.compile(r'AI8051U氢原子系统'),
            'neofetch_version': re.compile(r'版本:\s*(.+)'),
            'neofetch_author': re.compile(r'作者:\s*(.+)')
        }
        
        # 新增2.0.5版本的解析模式
        self.v205_patterns = {
            'clock_info_header': re.compile(r'AI8051U时钟系统详细信息'),
            'system_clock_config': re.compile(r'系统时钟配置:'),
            'sys_clock': re.compile(r'系统时钟\(SYSCLK\):\s*(.+)'),
            'pll_output': re.compile(r'PLL输出时钟:\s*([\d.]+MHz\s*\(.*\))|PLL输出时钟:\s*(.+)'),
            'high_speed_peripheral': re.compile(r'高速外设时钟:\s*(.+)'),
            'tfpu_clock_config': re.compile(r'TFPU时钟配置:'),
            'tfpu_clkdiv_reg': re.compile(r'TFPU_CLKDIV寄存器:\s*(.+)'),
            'prescaler': re.compile(r'预分频系数:\s*(.+)'),
            'calc_frequency': re.compile(r'计算频率:\s*(.+)'),
            'cpu_freq_ratio': re.compile(r'与CPU频率比:\s*(.+)'),
            'key_registers': re.compile(r'关键寄存器状态:'),
            'clksel_reg': re.compile(r'CLKSEL寄存器:\s*(.+)'),
            'usbclk_reg': re.compile(r'USBCLK寄存器:\s*(.+)'),
            't4t3m_reg': re.compile(r'T4T3M寄存器:\s*(.+)'),
            'dmair_reg': re.compile(r'DMAIR寄存器:\s*(.+)'),
            'conclusion': re.compile(r'结论:'),
            'tfpu_freq_verification': re.compile(r'TFPU运行在(.+)\s*\(需要进一步验证\)'),
            'tfpu_freq_conclusion': re.compile(r'TFPU运行在约(.+)\s*\(PLL时钟源，\d+分频\)'),
            'performance_header': re.compile(r'AI8051U 硬件加速性能基准测试'),
            'tfpu_status_check': re.compile(r'TFPU状态检查完成'),
            'mdu32_perf_header': re.compile(r'MDU32性能基准测试:'),
            'mdu32_multiply_avg': re.compile(r'乘法平均:\s*([\d.]+)\s*时钟周期/次'),
            'mdu32_multiply_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'mdu32_divide_avg': re.compile(r'除法平均:\s*([\d.]+)\s*时钟周期/次'),
            'mdu32_divide_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'tfpu_perf_header': re.compile(r'TFPU性能基准测试:'),
            'timing_warning': re.compile(r'\[计时异常\]\s*开始:(\d+)\s*结束:(\d+)\s*差值:(\d+)'),
            'warning_skip': re.compile(r'警告:\s*(.+)\s*第\d+轮测试计时异常，已跳过'),
            'tfpu_add_avg': re.compile(r'加法平均:\s*([\d.]+)\s*时钟周期/次'),
            'tfpu_add_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'tfpu_multiply_avg': re.compile(r'乘法平均:\s*([\d.]+)\s*时钟周期/次'),
            'tfpu_multiply_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'tfpu_divide_avg': re.compile(r'除法平均:\s*([\d.]+)\s*时钟周期/次'),
            'tfpu_divide_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'tfpu_sin_avg': re.compile(r'正弦平均:\s*([\d.]+)\s*时钟周期/次'),
            'tfpu_sin_ratio': re.compile(r'硬件加速比:\s*([\d.]+)x\s*\(理论\d+周期\)'),
            'hardware_state': re.compile(r'硬件状态:'),
            'tfpu_clock_source': re.compile(r'TFPU时钟源:\s*(.+)'),
            'cpu_clock_source': re.compile(r'CPU时钟:\s*(.+)'),
            'acceleration_ratio': re.compile(r'加速比:\s*(.+)'),
            'power_management': re.compile(r'功耗管理:\s*(.+)')
        }
    
    def _direct_parse_message(self, message: str) -> bool:
        """直接解析消息，不依赖正则表达式"""
        updated = False
        
        # 按行处理消息
        lines = message.split('\n')
        for line in lines:
            line = line.strip()
            if not line:
                continue
            
            # 直接匹配关键信息
            if '微控制器:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    mcu = parts[1].strip()
                    self.device_info['system']['mcu'] = mcu
                    if self.debug_mode:
                        debug_log(f"直接解析MCU: {mcu}", "DeviceInfoManager")
                    updated = True
            
            elif '时钟频率:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    freq = parts[1].strip()
                    self.device_info['system']['clock_frequency'] = freq
                    self.device_info['system']['clock'] = freq
                    self.device_info['system']['cpu_clock'] = freq
                    self.device_info['performance']['cpu_frequency'] = freq
                    
                    # 尝试提取TFPU频率
                    if 'TFPU:' in freq or 'tfpu:' in freq.lower():
                        # 简单提取TFPU频率
                        if '(' in freq and ')' in freq:
                            tfpu_part = freq[freq.find('(')+1:freq.find(')')]
                            if 'TFPU:' in tfpu_part:
                                tfpu_freq = tfpu_part.split(':', 1)[1].strip()
                                self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                                self.device_info['performance']['tfpu_enabled'] = True
                    
                    if self.debug_mode:
                        debug_log(f"直接解析时钟频率: {freq}", "DeviceInfoManager")
                    updated = True
            
            elif 'Flash大小:' in line or 'Flash:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    flash = parts[1].strip()
                    self.device_info['system']['flash_size'] = flash
                    self.device_info['system']['flash'] = flash
                    if self.debug_mode:
                        debug_log(f"直接解析Flash: {flash}", "DeviceInfoManager")
                    updated = True
            
            elif 'XRAM大小:' in line or 'XRAM:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    xram = parts[1].strip()
                    self.device_info['system']['xram_size'] = xram
                    self.device_info['system']['xram'] = xram
                    if self.debug_mode:
                        debug_log(f"直接解析XRAM: {xram}", "DeviceInfoManager")
                    updated = True
            
            elif 'USB-CDC:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    usb = parts[1].strip()
                    self.device_info['system']['usb_cdc'] = usb
                    if self.debug_mode:
                        debug_log(f"直接解析USB-CDC: {usb}", "DeviceInfoManager")
                    updated = True
            
            elif 'Flash已用:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    flash_used = parts[1].strip()
                    if 'memory' not in self.device_info:
                        self.device_info['memory'] = {}
                    self.device_info['memory']['flash_used'] = flash_used
                    if self.debug_mode:
                        debug_log(f"直接解析Flash已用: {flash_used}", "DeviceInfoManager")
                    updated = True
            
            elif '内部RAM:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    internal_ram = parts[1].strip()
                    if 'memory' not in self.device_info:
                        self.device_info['memory'] = {}
                    self.device_info['memory']['internal_ram'] = internal_ram
                    if self.debug_mode:
                        debug_log(f"直接解析内部RAM: {internal_ram}", "DeviceInfoManager")
                    updated = True
            
            elif '当前时间:' in line:
                parts = line.split(':', 1)
                if len(parts) > 1:
                    rtc_time = parts[1].strip()
                    self.device_info['status']['rtc_time'] = rtc_time
                    self.device_info['system']['rtc'] = rtc_time  # 同时设置system.rtc字段
                    if self.debug_mode:
                        debug_log(f"直接解析RTC时间: {rtc_time}", "DeviceInfoManager")
                    updated = True
        
        return updated
        
    def parse_message(self, message: str) -> bool:
        """解析消息并更新设备信息（带超时保护和去重机制）"""
        start_time = time.time()
        updated = False
        current_time = time.time()
        
        # 消息处理超时保护 - 最多处理5秒
        max_processing_time = 5.0
        
        # 调试信息
        if "微控制器" in message or "时钟频率" in message or "Flash" in message:
            debug_log(f"解析设备信息: {message.strip()}", "DeviceInfoManager")
        
        # 检查处理时间
        if time.time() - start_time > max_processing_time:
            if self.debug_mode:
                debug_log(f"消息处理超时，跳过: {message[:50]}...", "DeviceInfoManager")
            return False
        
        # 直接解析各种信息，不使用模式
        
        # 增强的直接解析逻辑 - 不依赖正则表达式
        updated = self._direct_parse_message(message) or updated
        
        # 解析UI显示格式的设备信息
        if '=== AI8051U 设备信息 ===' in message:
            # 标记进入UI设备信息解析模式
            self.device_info['status']['ui_device_info_mode'] = True
            if self.debug_mode:
                debug_log(f"进入UI设备信息解析模式", "DeviceInfoManager")
            updated = True
        
        # 解析UI设备信息模式中的具体信息
        elif self.device_info['status'].get('ui_device_info_mode', False):
            # 解析版本信息
            if '版本:' in message and '等待设备信息更新...' not in message:
                version_match = re.search(r'版本[:：]\s*(.+)', message)
                if version_match:
                    version = version_match.group(1).strip()
                    if version and version != '等待设备信息更新...':
                        self.device_info['system']['version'] = version
                        updated = True
                        if self.debug_mode:
                            debug_log(f"UI模式解析到版本信息: {version}", "DeviceInfoManager")
            
            # 解析作者信息
            elif '作者:' in message and '等待设备信息更新...' not in message:
                author_match = re.search(r'作者[:：]\s*(.+)', message)
                if author_match:
                    author = author_match.group(1).strip()
                    if author and author != '等待设备信息更新...':
                        self.device_info['system']['author'] = author
                        updated = True
                        if self.debug_mode:
                            debug_log(f"UI模式解析到作者信息: {author}", "DeviceInfoManager")
            
            # 解析RTC时钟信息
            elif 'RTC时钟:' in message:
                rtc_match = re.search(r'RTC时钟[:：]\s*(.+)', message)
                if rtc_match:
                    rtc_info = rtc_match.group(1).strip()
                    if rtc_info and rtc_info != '未知':
                        self.device_info['system']['rtc'] = rtc_info
                        self.device_info['status']['rtc_time'] = rtc_info
                        updated = True
                        if self.debug_mode:
                            debug_log(f"UI模式解析到RTC时钟: {rtc_info}", "DeviceInfoManager")
            
            # 检查是否结束UI设备信息模式
            elif '【性能数据】' in message or 'MDU32乘法性能:' in message:
                # 性能数据部分，保持模式继续解析
                pass
            elif message.strip() == '' or '===' in message:
                # 空行或新的分隔符表示结束
                self.device_info['status']['ui_device_info_mode'] = False
                if self.debug_mode:
                    debug_log(f"退出UI设备信息解析模式", "DeviceInfoManager")
        
        # 解析系统信息
        if self.patterns['system_info'].search(message):
            self.device_info['status']['system_info_mode'] = True
            self.mode_start_time['system_info_mode'] = current_time
            if self.debug_mode:
                debug_log(f"进入系统信息解析模式: {message.strip()}", "DeviceInfoManager")
            updated = True
        
        # 解析2.0.5版本的启动信息中的硬件加速配置
        if '硬件加速:' in message and 'MDU32' in message and 'TFPU' in message:
            parts = message.split(':', 1)
            if len(parts) > 1:
                hw_info = parts[1].strip()
                self.device_info['system']['hw_acceleration'] = hw_info
                # 解析MDU32和TFPU状态
                if 'MDU32' in hw_info:
                    self.device_info['hardware']['mdu32']['status'] = '已启用'
                    # 提取MDU32详细信息
                    mdu32_detail = re.search(r'MDU32\(([^)]+)\)', hw_info)
                    if mdu32_detail:
                        self.device_info['hardware']['mdu32']['description'] = mdu32_detail.group(1).strip()
                if 'TFPU' in hw_info:
                    self.device_info['hardware']['tfpu']['status'] = '已启用'
                    # 提取TFPU详细信息
                    tfpu_detail = re.search(r'TFPU\(([^)]+)\)', hw_info)
                    if tfpu_detail:
                        self.device_info['hardware']['tfpu']['description'] = tfpu_detail.group(1).strip()
                updated = True
        
        # 直接解析各种信息
        if self.patterns['mcu'].search(message):
            match = self.patterns['mcu'].search(message)
            self.device_info['system']['mcu'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到MCU信息: {match.group(1).strip()}")
            updated = True
        elif self.patterns['system_mcu'].search(message):
            match = self.patterns['system_mcu'].search(message)
            self.device_info['system']['mcu'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到MCU信息(新格式): {match.group(1).strip()}")
            updated = True
            
        if self.patterns['clock'].search(message):
            match = self.patterns['clock'].search(message)
            freq = match.group(1).strip()
            self.device_info['system']['clock_frequency'] = freq
            self.device_info['system']['clock'] = freq  # 兼容性字段
            # 同时更新CPU频率
            self.device_info['system']['cpu_clock'] = freq
            # 更新性能信息中的CPU频率
            self.device_info['performance']['cpu_frequency'] = freq
            # 尝试从时钟频率中提取TFPU频率
            if 'TFPU:' in freq or 'tfpu:' in freq.lower():
                tfpu_match = re.search(r'\(?TFPU[:\s]*([\d\.]+MHz)\)?', freq, re.IGNORECASE)
                if tfpu_match:
                    tfpu_freq = tfpu_match.group(1).strip()
                    self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                    self.device_info['performance']['tfpu_enabled'] = True
            if self.debug_mode:
                print(f"[DEBUG] 解析到时钟频率: {freq}")
            updated = True
        elif self.patterns['system_clock'].search(message):
            match = self.patterns['system_clock'].search(message)
            freq = match.group(1).strip()
            self.device_info['system']['clock_frequency'] = freq
            self.device_info['system']['clock'] = freq  # 兼容性字段
            # 同时更新CPU频率
            self.device_info['system']['cpu_clock'] = freq
            # 更新性能信息中的CPU频率
            self.device_info['performance']['cpu_frequency'] = freq
            # 尝试从时钟频率中提取TFPU频率
            if 'TFPU:' in freq or 'tfpu:' in freq.lower():
                tfpu_match = re.search(r'\(?TFPU[:\s]*([\d\.]+MHz)\)?', freq, re.IGNORECASE)
                if tfpu_match:
                    tfpu_freq = tfpu_match.group(1).strip()
                    self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                    self.device_info['performance']['tfpu_enabled'] = True
            if self.debug_mode:
                print(f"[DEBUG] 解析到时钟频率(新格式): {freq}")
            updated = True
            
        if self.patterns['flash'].search(message):
            match = self.patterns['flash'].search(message)
            size = match.group(1).strip()
            self.device_info['system']['flash_size'] = size
            self.device_info['system']['flash'] = size  # 兼容性字段
            if self.debug_mode:
                print(f"[DEBUG] 解析到Flash大小: {size}")
            updated = True
        elif self.patterns['system_flash'].search(message):
            match = self.patterns['system_flash'].search(message)
            size = match.group(1).strip()
            self.device_info['system']['flash_size'] = size
            self.device_info['system']['flash'] = size  # 兼容性字段
            if self.debug_mode:
                print(f"[DEBUG] 解析到Flash大小(新格式): {size}")
            updated = True
            
        if self.patterns['xram'].search(message):
            match = self.patterns['xram'].search(message)
            size = match.group(1).strip()
            self.device_info['system']['xram_size'] = size
            self.device_info['system']['xram'] = size  # 兼容性字段
            if self.debug_mode:
                print(f"[DEBUG] 解析到XRAM大小: {size}")
            updated = True
        elif self.patterns['system_xram'].search(message):
            match = self.patterns['system_xram'].search(message)
            size = match.group(1).strip()
            self.device_info['system']['xram_size'] = size
            self.device_info['system']['xram'] = size  # 兼容性字段
            if self.debug_mode:
                print(f"[DEBUG] 解析到XRAM大小(新格式): {size}")
            updated = True
            
        if self.patterns['usb_cdc'].search(message):
            match = self.patterns['usb_cdc'].search(message)
            self.device_info['system']['usb_cdc'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到USB-CDC状态: {match.group(1).strip()}")
            updated = True
        elif self.patterns['system_usb_cdc'].search(message):
            match = self.patterns['system_usb_cdc'].search(message)
            self.device_info['system']['usb_cdc'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到USB-CDC状态(新格式): {match.group(1).strip()}")
            updated = True
            
        if self.patterns['build_date'].search(message):
            match = self.patterns['build_date'].search(message)
            self.device_info['system']['build_date'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到编译日期: {match.group(1).strip()}")
            updated = True
            
        if self.patterns['build_time'].search(message):
            match = self.patterns['build_time'].search(message)
            self.device_info['system']['build_time'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到编译时间: {match.group(1).strip()}")
            updated = True
            
        if self.patterns['rtc_time'].search(message):
            match = self.patterns['rtc_time'].search(message)
            self.device_info['status']['rtc_time'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到RTC时间: {match.group(1).strip()}")
            updated = True
            
        if self.patterns['flash_constants'].search(message):
            try:
                match = self.patterns['flash_constants'].search(message)
                if match and 'memory' in self.device_info:
                    self.device_info['memory']['flash_constants'] = match.group(1).strip()
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到常量存储: {match.group(1).strip()}")
                    updated = True
            except Exception as e:
                if self.debug_mode:
                    print(f"[DEBUG] 解析常量存储失败: {e}")
        
        # 检查系统信息模式是否应该结束
        if self.device_info['status'].get('system_info_mode', False):
            # 更灵活的结束条件：如果收到内存使用信息、RTC时间信息或空行，说明系统信息解析完成
            if ('Flash已用:' in message or '内部RAM:' in message or '当前时间:' in message or 
                '内存使用:' in message or message.strip() == '' or '终端> ' in message):
                self.device_info['status']['system_info_mode'] = False
                if self.debug_mode:
                    print(f"[DEBUG] 系统信息解析模式结束: {message.strip()}")
                updated = True
                
                # 总是更新时间戳，无论设备信息是否有变化
                try:
                    self.device_info['status']['last_update'] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
                except Exception as e:
                    if self.debug_mode:
                        print(f"[DEBUG] 更新状态时间失败: {e}")
                
                # 更智能的去重检查 - 分别处理内容和时间戳
                current_info_hash = self._calculate_device_info_hash()
                current_time = time.time()
                
                # 计算内容哈希（用于内容去重）
                content_fingerprint = self._generate_content_fingerprint(current_info_hash)
                
                # 内容去重检查（更短窗口，避免重复内容）
                content_is_duplicate = False
                if (self.last_content_hash == content_fingerprint and 
                    current_time - self.last_update_time <= self.content_dedup_window):
                    content_is_duplicate = True
                
                # 检查是否需要发送更新信号
                should_emit = False
                update_reason = ""
                
                if current_info_hash != self.last_device_info_hash:
                    # 设备信息内容发生变化
                    should_emit = True
                    update_reason = "内容变化"
                elif current_time - self.last_update_time > self.dedup_window:
                    # 时间戳窗口过期，允许更新
                    should_emit = True
                    update_reason = "时间戳窗口过期"
                elif not content_is_duplicate:
                    # 内容不重复，允许更新
                    should_emit = True
                    update_reason = "内容不重复"
                
                # 总是更新时间戳和状态
                self.last_device_info_hash = current_info_hash
                self.last_content_hash = content_fingerprint
                self.last_update_time = current_time
                
                # 根据条件发送更新信号
                if should_emit:
                    self._safe_emit_device_info_update()
                    if self.debug_mode:
                        print(f"[DEBUG] 设备信息已更新（{update_reason}），哈希: {current_info_hash[:8]}...")
                else:
                    # 只更新时间戳，不发送完整的设备信息更新信号
                    if self.debug_mode:
                        print(f"[DEBUG] 设备信息未变化，但时间戳已更新")
                
                updated = True  # 确保总是返回True，表示设备信息已被处理
                return updated  # 提前返回，避免重复处理
        
        # 解析硬件测试信息
        if '硬件加速单元测试' in message:
            self.device_info['status']['hardware_test_mode'] = True
            self.mode_start_time['hardware_test_mode'] = current_time
            self.device_info['hardware']['mdu32']['status'] = '测试中'
            self.device_info['hardware']['tfpu']['status'] = '测试中'
            updated = True
            
        elif self.device_info['status'].get('hardware_test_mode', False):
            if 'MDU32硬件乘除单元测试:' in message:
                self.device_info['hardware']['mdu32']['status'] = '测试中'
                updated = True
            elif 'TFPU浮点运算单元测试:' in message:
                self.device_info['hardware']['tfpu']['status'] = '测试中'
                updated = True
            elif self.patterns['mdu32_multiply'].search(message):
                match = self.patterns['mdu32_multiply'].search(message)
                self.device_info['hardware']['mdu32']['multiply_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['mdu32_multiply_time'].search(message):
                match = self.patterns['mdu32_multiply_time'].search(message)
                self.device_info['hardware']['mdu32']['multiply_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['mdu32_multiply_ratio'].search(message):
                match = self.patterns['mdu32_multiply_ratio'].search(message)
                self.device_info['hardware']['mdu32']['multiply_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['mdu32_divide'].search(message):
                match = self.patterns['mdu32_divide'].search(message)
                self.device_info['hardware']['mdu32']['divide_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['mdu32_divide_time'].search(message):
                match = self.patterns['mdu32_divide_time'].search(message)
                self.device_info['hardware']['mdu32']['divide_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['mdu32_divide_ratio'].search(message):
                match = self.patterns['mdu32_divide_ratio'].search(message)
                self.device_info['hardware']['mdu32']['divide_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_add'].search(message):
                match = self.patterns['tfpu_add'].search(message)
                self.device_info['hardware']['tfpu']['add_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_add_time'].search(message):
                match = self.patterns['tfpu_add_time'].search(message)
                self.device_info['hardware']['tfpu']['add_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_add_ratio'].search(message):
                match = self.patterns['tfpu_add_ratio'].search(message)
                self.device_info['hardware']['tfpu']['add_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_multiply'].search(message):
                match = self.patterns['tfpu_multiply'].search(message)
                self.device_info['hardware']['tfpu']['multiply_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_multiply_time'].search(message):
                match = self.patterns['tfpu_multiply_time'].search(message)
                self.device_info['hardware']['tfpu']['multiply_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_multiply_ratio'].search(message):
                match = self.patterns['tfpu_multiply_ratio'].search(message)
                self.device_info['hardware']['tfpu']['multiply_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sin'].search(message):
                match = self.patterns['tfpu_sin'].search(message)
                self.device_info['hardware']['tfpu']['sin_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sin_time'].search(message):
                match = self.patterns['tfpu_sin_time'].search(message)
                self.device_info['hardware']['tfpu']['sin_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sin_ratio'].search(message):
                match = self.patterns['tfpu_sin_ratio'].search(message)
                self.device_info['hardware']['tfpu']['sin_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_cos'].search(message):
                match = self.patterns['tfpu_cos'].search(message)
                self.device_info['hardware']['tfpu']['cos_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_cos_time'].search(message):
                match = self.patterns['tfpu_cos_time'].search(message)
                self.device_info['hardware']['tfpu']['cos_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_cos_ratio'].search(message):
                match = self.patterns['tfpu_cos_ratio'].search(message)
                self.device_info['hardware']['tfpu']['cos_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sqrt'].search(message):
                match = self.patterns['tfpu_sqrt'].search(message)
                self.device_info['hardware']['tfpu']['sqrt_result'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sqrt_time'].search(message):
                match = self.patterns['tfpu_sqrt_time'].search(message)
                self.device_info['hardware']['tfpu']['sqrt_time'] = match.group(1).strip()
                updated = True
            elif self.patterns['tfpu_sqrt_ratio'].search(message):
                match = self.patterns['tfpu_sqrt_ratio'].search(message)
                self.device_info['hardware']['tfpu']['sqrt_ratio'] = match.group(1).strip()
                updated = True
            elif self.patterns['hardware_status'].search(message):
                self.device_info['status']['hardware_test_mode'] = False
                self.device_info['hardware']['mdu32']['status'] = '完成'
                self.device_info['hardware']['tfpu']['status'] = '完成'
                updated = True
                self._safe_emit_device_info_update()
        # 解析时钟信息 (2.0.5版本新增)
        elif self.v205_patterns['clock_info_header'].search(message):
            self.device_info['status']['clock_info_mode'] = True
            updated = True
        elif self.device_info['status'].get('clock_info_mode', False):
            # 确保clock_system字典存在
            if 'clock_system' not in self.device_info:
                self.device_info['clock_system'] = {
                    'system_clock': '',
                    'pll_output_clock': '',
                    'high_speed_peripheral_clock': '',
                    'tfpu_clock_divider': '',
                    'prescaler_coefficient': '',
                    'calculated_frequency': '',
                    'cpu_frequency_ratio': '',
                    'clksel_register': '',
                    'usbclk_register': '',
                    't4t3m_register': '',
                    'dmair_register': '',
                    'tfpu_frequency_verification': '',
                    'conclusion': ''
                }
            if self.v205_patterns['system_clock_config'].search(message):
                updated = True
            elif self.v205_patterns['sys_clock'].search(message):
                match = self.v205_patterns['sys_clock'].search(message)
                self.device_info['clock_system']['system_clock'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['pll_output'].search(message):
                match = self.v205_patterns['pll_output'].search(message)
                # 处理两种格式的PLL输出时钟信息
                if match.group(1):
                    self.device_info['clock_system']['pll_output_clock'] = match.group(1).strip()
                elif match.group(2):
                    self.device_info['clock_system']['pll_output_clock'] = match.group(2).strip()
                updated = True
            elif self.v205_patterns['high_speed_peripheral'].search(message):
                match = self.v205_patterns['high_speed_peripheral'].search(message)
                self.device_info['clock_system']['high_speed_peripheral_clock'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['tfpu_clkdiv_reg'].search(message):
                match = self.v205_patterns['tfpu_clkdiv_reg'].search(message)
                self.device_info['clock_system']['tfpu_clock_divider'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['prescaler'].search(message):
                match = self.v205_patterns['prescaler'].search(message)
                self.device_info['clock_system']['prescaler_coefficient'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['calc_frequency'].search(message):
                match = self.v205_patterns['calc_frequency'].search(message)
                self.device_info['clock_system']['calculated_frequency'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['cpu_freq_ratio'].search(message):
                match = self.v205_patterns['cpu_freq_ratio'].search(message)
                self.device_info['clock_system']['cpu_frequency_ratio'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['clksel_reg'].search(message):
                match = self.v205_patterns['clksel_reg'].search(message)
                self.device_info['clock_system']['clksel_register'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['usbclk_reg'].search(message):
                match = self.v205_patterns['usbclk_reg'].search(message)
                self.device_info['clock_system']['usbclk_register'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['t4t3m_reg'].search(message):
                match = self.v205_patterns['t4t3m_reg'].search(message)
                self.device_info['clock_system']['t4t3m_register'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['dmair_reg'].search(message):
                match = self.v205_patterns['dmair_reg'].search(message)
                self.device_info['clock_system']['dmair_register'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['tfpu_freq_verification'].search(message):
                match = self.v205_patterns['tfpu_freq_verification'].search(message)
                self.device_info['clock_system']['tfpu_frequency_verification'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['tfpu_freq_conclusion'].search(message):
                match = self.v205_patterns['tfpu_freq_conclusion'].search(message)
                self.device_info['clock_system']['tfpu_frequency_verification'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['conclusion'].search(message):
                self.device_info['status']['clock_info_mode'] = False
                updated = True
                self._safe_emit_device_info_update()
                
        # 解析详细性能基准测试 (2.0.5版本新增)
        elif self.v205_patterns['performance_header'].search(message):
            self.device_info['status']['performance_mode'] = True
            self.device_info['current_test_unit'] = ''
            updated = True
        elif self.device_info['status'].get('performance_mode', False):
            # 确保performance字典存在
            if 'performance' not in self.device_info:
                self.device_info['performance'] = {
                    'mdu32_multiply_perf': '',
                    'mdu32_multiply_avg': '',
                    'mdu32_multiply_ratio': '',
                    'mdu32_divide_perf': '',
                    'mdu32_divide_avg': '',
                    'mdu32_divide_ratio': '',
                    'tfpu_add_perf': '',
                    'tfpu_add_avg': '',
                    'tfpu_add_ratio': '',
                    'tfpu_add_time': '',
                    'tfpu_multiply_perf': '',
                    'tfpu_multiply_avg': '',
                    'tfpu_multiply_ratio': '',
                    'tfpu_multiply_time': '',
                    'tfpu_divide_avg': '',
                    'tfpu_divide_ratio': '',
                    'tfpu_sin_avg': '',
                    'tfpu_sin_ratio': '',
                    'tfpu_sin_time': '',
                    'tfpu_sqrt_time': '',
                    'tfpu_cos_time': '',
                    'benchmark_completed': False,
                    'last_warning': '',
                    'timing_warnings': []
                }
            if self.v205_patterns['timing_warning'].search(message):
                match = self.v205_patterns['timing_warning'].search(message)
                warning_info = {
                    'start': match.group(1),
                    'end': match.group(2),
                    'diff': match.group(3)
                }
                self.device_info['performance']['timing_warnings'].append(warning_info)
                updated = True
            elif 'MDU32性能基准测试:' in message:
                self.device_info['current_test_unit'] = 'MDU32'
                updated = True
            elif 'TFPU性能基准测试:' in message:
                self.device_info['current_test_unit'] = 'TFPU'
                updated = True
            elif self.v205_patterns['warning_skip'].search(message):
                match = self.v205_patterns['warning_skip'].search(message)
                self.device_info['performance']['last_warning'] = match.group(1).strip()
                updated = True
            elif '乘法平均:' in message and '时钟周期/次' in message and self.device_info['status'].get('performance_mode', False):
                match = re.search(r'乘法平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    # 判断是MDU32还是TFPU的乘法平均
                    if 'MDU32' in str(self.device_info.get('current_test_unit', '')):
                        self.device_info['performance']['mdu32_multiply_avg'] = f"{match.group(1)}时钟周期/次"
                    else:
                        self.device_info['performance']['tfpu_multiply_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '硬件加速比:' in message and 'x' in message and self.device_info['status'].get('performance_mode', False):
                match = re.search(r'硬件加速比: ([\d.]+)x', message)
                if match:
                    # 判断是MDU32还是TFPU的加速比
                    current_unit = str(self.device_info.get('current_test_unit', ''))
                    if 'MDU32' in current_unit:
                        if self._check_performance_ratio('mdu32_multiply', 'mdu32_multiply_ratio'):
                            self.device_info['performance']['mdu32_multiply_ratio'] = f"{match.group(1)}x"
                        elif not self.device_info['performance'].get('mdu32_divide_ratio'):
                            self.device_info['performance']['mdu32_divide_ratio'] = f"{match.group(1)}x"
                    elif 'TFPU' in current_unit:
                        if self.device_info['performance'].get('tfpu_add_avg') and not self.device_info['performance'].get('tfpu_add_ratio'):
                            self.device_info['performance']['tfpu_add_ratio'] = f"{match.group(1)}x"
                        elif self._check_performance_ratio('tfpu_multiply', 'tfpu_multiply_ratio'):
                            self.device_info['performance']['tfpu_multiply_ratio'] = f"{match.group(1)}x"
                        elif not self.device_info['performance'].get('tfpu_sin_ratio'):
                            self.device_info['performance']['tfpu_sin_ratio'] = f"{match.group(1)}x"
                    updated = True
            elif '除法平均:' in message and '时钟周期/次' in message and self.device_info['status'].get('performance_mode', False):
                match = re.search(r'除法平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    self.device_info['performance']['mdu32_divide_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '加法平均:' in message and '时钟周期/次' in message and self.device_info['status'].get('performance_mode', False):
                match = re.search(r'加法平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    self.device_info['performance']['tfpu_add_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '正弦平均:' in message and '时钟周期/次' in message and self.device_info['status'].get('performance_mode', False):
                match = re.search(r'正弦平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    self.device_info['performance']['tfpu_sin_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif self.v205_patterns['tfpu_multiply_avg'].search(message):
                match = self.v205_patterns['tfpu_multiply_avg'].search(message)
                self.device_info['performance']['tfpu_multiply_avg'] = f"{match.group(1)}时钟周期/次"
                updated = True
            elif self.v205_patterns['tfpu_multiply_ratio'].search(message):
                match = self.v205_patterns['tfpu_multiply_ratio'].search(message)
                self.device_info['performance']['tfpu_multiply_ratio'] = f"{match.group(1)}x"
                updated = True
            elif self.v205_patterns['tfpu_divide_avg'].search(message):
                match = self.v205_patterns['tfpu_divide_avg'].search(message)
                self.device_info['performance']['tfpu_divide_avg'] = f"{match.group(1)}时钟周期/次"
                updated = True
            elif self.v205_patterns['tfpu_divide_ratio'].search(message):
                match = self.v205_patterns['tfpu_divide_ratio'].search(message)
                self.device_info['performance']['tfpu_divide_ratio'] = f"{match.group(1)}x"
                updated = True
            elif self.v205_patterns['tfpu_sin_avg'].search(message):
                match = self.v205_patterns['tfpu_sin_avg'].search(message)
                self.device_info['performance']['tfpu_sin_avg'] = f"{match.group(1)}时钟周期/次"
                updated = True
            elif self.v205_patterns['tfpu_sin_ratio'].search(message):
                match = self.v205_patterns['tfpu_sin_ratio'].search(message)
                self.device_info['performance']['tfpu_sin_ratio'] = f"{match.group(1)}x"
                updated = True
            elif self.v205_patterns['tfpu_clock_source'].search(message):
                match = self.v205_patterns['tfpu_clock_source'].search(message)
                self.device_info['system']['tfpu_clock'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['cpu_clock_source'].search(message):
                match = self.v205_patterns['cpu_clock_source'].search(message)
                self.device_info['system']['cpu_clock'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['acceleration_ratio'].search(message):
                match = self.v205_patterns['acceleration_ratio'].search(message)
                self.device_info['system']['acceleration_ratio'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['power_management'].search(message):
                match = self.v205_patterns['power_management'].search(message)
                self.device_info['system']['power_management'] = match.group(1).strip()
                updated = True
            elif '性能基准测试完成！' in message:
                self.device_info['status']['performance_mode'] = False
                self.device_info['performance']['benchmark_completed'] = True
                updated = True
                self._safe_emit_device_info_update()
                
        # 解析性能数据
        elif '性能基准测试:' in message:
            self.device_info['status']['performance_mode'] = True
            updated = True
        
        # 性能数据解析 - 独立的条件检查
        if self.device_info['status'].get('performance_mode', False):
            # 确保performance字典存在
            if 'performance' not in self.device_info:
                self.device_info['performance'] = {
                    'mdu32_multiply_perf': '',
                    'mdu32_multiply_avg': '',
                    'mdu32_multiply_ratio': '',
                    'mdu32_divide_perf': '',
                    'mdu32_divide_avg': '',
                    'mdu32_divide_ratio': '',
                    'tfpu_add_perf': '',
                    'tfpu_add_avg': '',
                    'tfpu_add_ratio': '',
                    'tfpu_add_time': '',
                    'tfpu_multiply_perf': '',
                    'tfpu_multiply_avg': '',
                    'tfpu_multiply_ratio': '',
                    'tfpu_multiply_time': '',
                    'tfpu_divide_avg': '',
                    'tfpu_divide_ratio': '',
                    'tfpu_sin_avg': '',
                    'tfpu_sin_ratio': '',
                    'tfpu_sin_time': '',
                    'tfpu_sqrt_time': '',
                    'tfpu_cos_time': '',
                    'benchmark_completed': False,
                    'last_warning': '',
                    'timing_warnings': []
                }
            
            # 解析性能数据
            if '乘法性能:' in message:
                match = re.search(r'乘法性能: (\d+)次运算耗时 (\d+) 时钟周期', message)
                if match:
                    self.device_info['performance']['mdu32_multiply_perf'] = f"{match.group(2)}时钟周期/{match.group(1)}次"
                    updated = True
            elif '平均每次:' in message:
                match = re.search(r'平均每次: ([\d.]+) 时钟周期', message)
                if match:
                    # 根据上下文判断是乘法还是除法平均
                    if self.device_info['performance'].get('mdu32_multiply_perf') and not self.device_info['performance'].get('mdu32_multiply_avg'):
                        self.device_info['performance']['mdu32_multiply_avg'] = f"{match.group(1)}时钟周期/次"
                    elif self.device_info['performance'].get('mdu32_divide_perf') and not self.device_info['performance'].get('mdu32_divide_avg'):
                        self.device_info['performance']['mdu32_divide_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '加法性能:' in message:
                match = re.search(r'加法性能: (\d+)次运算耗时 (\d+) 时钟周期', message)
                if match:
                    self.device_info['performance']['tfpu_add_perf'] = f"{match.group(2)}时钟周期/{match.group(1)}次"
                    updated = True
            elif '除法性能:' in message:
                match = re.search(r'除法性能: (\d+)次运算耗时 (\d+) 时钟周期', message)
                if match:
                    self.device_info['performance']['mdu32_divide_perf'] = f"{match.group(2)}时钟周期/{match.group(1)}次"
                    updated = True
            elif '乘法平均:' in message and '时钟周期/次' in message:
                match = re.search(r'乘法平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    self.device_info['performance']['tfpu_multiply_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '正弦平均:' in message and '时钟周期/次' in message:
                match = re.search(r'正弦平均: ([\d.]+) 时钟周期/次', message)
                if match:
                    self.device_info['performance']['tfpu_sin_avg'] = f"{match.group(1)}时钟周期/次"
                    updated = True
            elif '性能基准测试完成！' in message:
                self.device_info['status']['performance_mode'] = False
                self.device_info['performance']['benchmark_completed'] = True
                updated = True
                self._safe_emit_device_info_update()
                
        # 解析电压信息
        elif '电源电压测量结果:' in message:
            self.device_info['status']['voltage_mode'] = True
            updated = True
        elif self.device_info['status'].get('voltage_mode', False):
            if self.patterns['voltage'].search(message):
                match = self.patterns['voltage'].search(message)
                self.device_info['hardware']['adc']['voltage'] = match.group(1).strip()
                updated = True
            elif self.patterns['voltage_raw'].search(message):
                match = self.patterns['voltage_raw'].search(message)
                self.device_info['hardware']['adc']['raw_value'] = match.group(1).strip()
                updated = True
            elif self.patterns['voltage_channel'].search(message):
                match = self.patterns['voltage_channel'].search(message)
                self.device_info['hardware']['adc']['channel'] = match.group(1).strip()
                updated = True
            elif self.patterns['voltage_reference'].search(message):
                match = self.patterns['voltage_reference'].search(message)
                self.device_info['hardware']['adc']['reference'] = match.group(1).strip()
                updated = True
            elif self.patterns['voltage_resolution'].search(message):
                match = self.patterns['voltage_resolution'].search(message)
                self.device_info['hardware']['adc']['resolution'] = match.group(1).strip()
                updated = True
            elif self.patterns['voltage_samples'].search(message):
                match = self.patterns['voltage_samples'].search(message)
                self.device_info['hardware']['adc']['samples'] = match.group(1).strip()
                updated = True
            elif message.strip() == '终端> ':
                self.device_info['status']['voltage_mode'] = False
                updated = True
                self._safe_emit_device_info_update()
                
        # 解析内存使用信息 - 增强版本（带异常处理）
        elif '内存使用:' in message:
            try:
                self.device_info['status']['memory_mode'] = True
                updated = True
                if self.debug_mode:
                    print(f"[DEBUG] 进入内存使用解析模式")
            except Exception as e:
                if self.debug_mode:
                    print(f"[DEBUG] 设置内存模式失败: {e}")
        elif (self.device_info['status'].get('memory_mode', False) or 
              '内存使用:' in message or 'Flash已用:' in message or 
              'XRAM已用:' in message or '内部RAM:' in message):
            try:
                # 确保 memory 字段存在
                if 'memory' not in self.device_info:
                    self.device_info['memory'] = {
                        'flash_used': '',
                        'flash_constants': '',
                        'xram_used': '',
                        'internal_ram_used': ''
                    }
                
                if self.patterns['flash_used'].search(message):
                    match = self.patterns['flash_used'].search(message)
                    if match:
                        self.device_info['memory']['flash_used'] = match.group(1).strip()
                        if self.debug_mode:
                            print(f"[DEBUG] 解析到Flash已用: {match.group(1).strip()}")
                        updated = True
                elif self.patterns['xram_used'].search(message):
                    match = self.patterns['xram_used'].search(message)
                    if match:
                        self.device_info['memory']['xram_used'] = match.group(1).strip()
                        if self.debug_mode:
                            print(f"[DEBUG] 解析到XRAM已用: {match.group(1).strip()}")
                        updated = True
                elif self.patterns['internal_ram'].search(message):
                    match = self.patterns['internal_ram'].search(message)
                    if match:
                        self.device_info['memory']['internal_ram_used'] = match.group(1).strip()
                        if self.debug_mode:
                            print(f"[DEBUG] 解析到内部RAM: {match.group(1).strip()}")
                        updated = True
                elif '常量存储:' in message:
                    # 解析常量存储信息
                    parts = message.split(':', 1)  # 只分割第一个冒号
                    if len(parts) > 1:
                        self.device_info['memory']['flash_constants'] = parts[1].strip()
                        if self.debug_mode:
                            print(f"[DEBUG] 解析到常量存储: {parts[1].strip()}")
                        updated = True
                # 检查内存信息是否结束
                elif (message.strip() == '' or message.strip() == '终端> ' or 
                      (self.device_info.get('memory', {}).get('flash_used') and 
                       self.device_info.get('memory', {}).get('xram_used') and 
                       self.device_info.get('memory', {}).get('internal_ram_used'))):
                    self.device_info['status']['memory_mode'] = False
                    if self.debug_mode:
                        print(f"[DEBUG] 内存使用解析模式结束")
                    updated = True
                    self._safe_emit_device_info_update()
            except (AttributeError, KeyError, IndexError) as e:
                # 特定异常不需要打印，避免噪音
                if self.debug_mode:
                    print(f"[DEBUG] 内存信息解析轻微错误: {type(e).__name__}")
                # 不重置内存模式，继续解析下一条消息
            except Exception as e:
                if self.debug_mode:
                    print(f"[DEBUG] 解析内存信息失败: {e}")
                # 发生错误时重置内存模式
                try:
                    self.device_info['status']['memory_mode'] = False
                except:
                    pass
                
        # 解析neofetch信息
        # 注意：AI8051U氢原子系统现在由system_startup_mode处理
        # 不再使用neofetch_system模式检测
        elif self.device_info['status'].get('neofetch_mode', False):
            if self.patterns['neofetch_version'].search(message):
                match = self.patterns['neofetch_version'].search(message)
                self.device_info['system']['version'] = match.group(1).strip()
                updated = True
            elif self.patterns['neofetch_author'].search(message):
                match = self.patterns['neofetch_author'].search(message)
                self.device_info['system']['author'] = match.group(1).strip()
                updated = True
            elif message.strip() == '║系统就绪║':
                self.device_info['status']['neofetch_mode'] = False
                updated = True
                self._safe_emit_device_info_update()
        # 解析reset命令输出中的版本和作者信息
        elif '版本:' in message:
            # 更精确的版本信息解析，支持多种格式
            version_match = re.search(r'版本[:：]\s*(.+)', message)
            if version_match:
                self.device_info['system']['version'] = version_match.group(1).strip()
                updated = True
                if self.debug_mode:
                    print(f"[DEBUG] 解析到版本信息: {self.device_info['system']['version']}")
                # 立即发送更新信号，确保UI同步更新
                self._safe_emit_device_info_update()
        elif '作者:' in message:
            # 更精确的作者信息解析，支持多种格式
            author_match = re.search(r'作者[:：]\s*(.+)', message)
            if author_match:
                self.device_info['system']['author'] = author_match.group(1).strip()
                updated = True
                if self.debug_mode:
                    print(f"[DEBUG] 解析到作者信息: {self.device_info['system']['author']}")
                # 立即发送更新信号，确保UI同步更新
                self._safe_emit_device_info_update()
        elif 'AI8051U氢原子系统' in message:
            self.device_info['system']['system'] = 'AI8051U氢原子系统'
            updated = True
            if self.debug_mode:
                print(f"[DEBUG] 解析到系统名称: AI8051U氢原子系统")
        # 解析reset命令的启动信息
        elif '正在启动' in message or '系统启动' in message:
            # reset命令启动信息，更新时间戳
            self.device_info['status']['last_update'] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
            updated = True
            if self.debug_mode:
                print(f"[DEBUG] 检测到系统启动信息: {message.strip()}")
        
        # 更灵活的版本和作者信息解析
        elif any(keyword in message.lower() for keyword in ['version', 'ver']):
            # 尝试从各种格式中提取版本信息
            version_patterns = [
                r'ver[sion]*[:\s]*([vV]?[\d\.]+[a-zA-Z0-9\-_]*)',
                r'([vV]?[\d\.]+[a-zA-Z0-9\-_]*)',
                r'版本[:\s]*([vV]?[\d\.]+[a-zA-Z0-9\-_]*)'
            ]
            for pattern in version_patterns:
                match = re.search(pattern, message)
                if match:
                    self.device_info['system']['version'] = match.group(1).strip()
                    updated = True
                    print(f"[DEBUG] 灵活解析到版本信息: {self.device_info['system']['version']}")
                    # 立即发送更新信号，确保UI同步更新
                    self._safe_emit_device_info_update()
                    break
        
        elif any(keyword in message.lower() for keyword in ['author', 'by']):
            # 尝试从各种格式中提取作者信息
            author_patterns = [
                r'author[:\s]*([a-zA-Z0-9\u4e00-\u9fff\s]+)',
                r'by[:\s]*([a-zA-Z0-9\u4e00-\u9fff\s]+)',
                r'作者[:\s]*([a-zA-Z0-9\u4e00-\u9fff\s]+)'
            ]
            for pattern in author_patterns:
                match = re.search(pattern, message)
                if match:
                    author = match.group(1).strip()
                    if len(author) > 0 and len(author) < 50:  # 合理的作者名长度
                        self.device_info['system']['author'] = author
                        updated = True
                        print(f"[DEBUG] 灵活解析到作者信息: {self.device_info['system']['author']}")
                        # 立即发送更新信号，确保UI同步更新
                        self._safe_emit_device_info_update()
                        break
                
        # 解析硬件状态信息
        elif self.patterns['tfpu_clock'].search(message):
            match = self.patterns['tfpu_clock'].search(message)
            tfpu_freq = match.group(1).strip()
            self.device_info['system']['tfpu_clock'] = tfpu_freq
            # 更新性能信息中的TFPU频率
            self.device_info['performance']['tfpu_frequency'] = tfpu_freq
            self.device_info['performance']['tfpu_enabled'] = True
            updated = True
        elif self.patterns['cpu_clock'].search(message):
            match = self.patterns['cpu_clock'].search(message)
            cpu_freq = match.group(1).strip()
            self.device_info['system']['cpu_clock'] = cpu_freq
            # 更新性能信息中的CPU频率
            self.device_info['performance']['cpu_frequency'] = cpu_freq
            updated = True
        elif self.patterns['tfpu_clkdiv_reg'].search(message):
            match = self.patterns['tfpu_clkdiv_reg'].search(message)
            self.device_info['system']['tfpu_clkdiv_reg'] = match.group(1).strip()
            if self.debug_mode:
                print(f"[DEBUG] 解析到TFPU_CLKDIV寄存器: {match.group(1).strip()}")
            updated = True
        elif self.patterns['rtc_time'].search(message):
            match = self.patterns['rtc_time'].search(message)
            self.device_info['system']['rtc'] = match.group(1).strip()
            updated = True
        # 解析硬件加速信息（包含版本、作者、编译信息的新格式）
        elif '硬件加速:' in message:
            parts = message.split(':', 1)  # 只分割第一个冒号
            if len(parts) > 1:
                hw_info = parts[1].strip()
                self.device_info['system']['hw_acceleration'] = hw_info
                # 解析MDU32和TFPU状态
                if 'MDU32' in hw_info:
                    self.device_info['hardware']['mdu32']['status'] = '已启用'
                if 'TFPU' in hw_info:
                    self.device_info['hardware']['tfpu']['status'] = '已启用'
                    # 更新性能信息中的TFPU启用状态
                    self.device_info['performance']['tfpu_enabled'] = True
                
                # 设置硬件加速信息
                self.device_info['system']['hw_acceleration'] = hw_info
                updated = True
                if self.debug_mode if hasattr(self, 'debug_mode') else False:
                    print(f"[DEBUG] 解析到硬件加速信息: {self.device_info['system']['hw_acceleration']}")
                    
        # 增强解析：处理reset命令的完整输出格式
        # 格式示例：
        # AI8051U氢原子系统
        # 版本: 2.1.0
        # 作者: 076lik
        # 编译: 2025年12月03日 18:51:45
        # ========================================
        # 系统信息:
        #   CPU时钟: 30MHz (TFPU: 90MHz)
        #   Flash: 64KB
        #   XRAM: 32KB
        #   硬件加速: MDU32(32位乘除单元), TFPU(浮点运算+三角函数)
        elif 'AI8051U氢原子系统' in message:
            # 标记进入系统启动信息解析模式（系统名称在下面的elif块中设置）
            self.device_info['status']['system_startup_mode'] = True
            updated = True
            if self.debug_mode:
                print(f"[DEBUG] 进入系统启动信息解析模式")
                
        elif self.device_info['status'].get('system_startup_mode', False):
            # 解析版本信息
            if '版本:' in message:
                version_match = re.search(r'版本[:：]\s*(.+)', message)
                if version_match:
                    self.device_info['system']['version'] = version_match.group(1).strip()
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到版本信息: {self.device_info['system']['version']}")
            
            # 解析作者信息
            elif '作者:' in message:
                author_match = re.search(r'作者[:：]\s*(.+)', message)
                if author_match:
                    self.device_info['system']['author'] = author_match.group(1).strip()
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到作者信息: {self.device_info['system']['author']}")
            
            # 解析编译信息
            elif '编译:' in message:
                compile_match = re.search(r'编译[:：]\s*(.+)', message)
                if compile_match:
                    compile_info = compile_match.group(1).strip()
                    # 尝试从编译信息中提取日期和时间
                    date_match = re.search(r'(\d{4}年\d{1,2}月\d{1,2}日)', compile_info)
                    time_match = re.search(r'(\d{1,2}:\d{1,2}:\d{1,2})', compile_info)
                    
                    if date_match:
                        self.device_info['system']['build_date'] = date_match.group(1).strip()
                    if time_match:
                        self.device_info['system']['build_time'] = time_match.group(1).strip()
                    
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到编译信息: {compile_info}")
            
            # 解析CPU时钟信息（可能包含TFPU时钟）
            elif 'CPU时钟:' in message:
                cpu_match = re.search(r'CPU时钟[:：]\s*(.+)', message)
                if cpu_match:
                    cpu_info = cpu_match.group(1).strip()
                    self.device_info['system']['cpu_clock'] = cpu_info
                    # 更新性能信息中的CPU频率
                    self.device_info['performance']['cpu_frequency'] = cpu_info
                    # 尝试从CPU时钟信息中提取TFPU时钟
                    tfpu_match = re.search(r'TFPU[:：]\s*([\d\.]+MHz)', cpu_info)
                    if tfpu_match:
                        tfpu_freq = tfpu_match.group(1).strip()
                        self.device_info['system']['tfpu_clock'] = tfpu_freq
                        # 更新性能信息中的TFPU频率
                        self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                        self.device_info['performance']['tfpu_enabled'] = True
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到CPU时钟信息: {cpu_info}")
            
            # 解析Flash信息
            elif 'Flash:' in message:
                flash_match = re.search(r'Flash[:：]\s*(.+)', message)
                if flash_match:
                    self.device_info['system']['flash_size'] = flash_match.group(1).strip()
                    self.device_info['system']['flash'] = flash_match.group(1).strip()  # 兼容性字段
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到Flash信息: {self.device_info['system']['flash_size']}")
            
            # 解析XRAM信息
            elif 'XRAM:' in message:
                xram_match = re.search(r'XRAM[:：]\s*(.+)', message)
                if xram_match:
                    self.device_info['system']['xram_size'] = xram_match.group(1).strip()
                    self.device_info['system']['xram'] = xram_match.group(1).strip()  # 兼容性字段
                    updated = True
                    if self.debug_mode:
                        print(f"[DEBUG] 解析到XRAM信息: {self.device_info['system']['xram_size']}")
            
            # 检查是否结束系统启动信息解析模式
            # 当遇到分隔线或系统信息结束标志时退出
            elif '========================================' in message or '系统信息:' in message:
                # 继续解析，不退出模式，因为后面还有更多系统信息
                updated = True
            elif '可用命令:' in message or '基础命令:' in message:
                # 遇到命令列表，说明系统信息部分结束
                self.device_info['status']['system_startup_mode'] = False
                updated = True
                # 发送设备信息更新信号
                self._safe_emit_device_info_update()
                if self.debug_mode:
                    print(f"[DEBUG] 系统启动信息解析完成，已发送更新信号")
                    
        # 解析2.0.5版本的硬件状态详细信息
        elif self.v205_patterns['hardware_state'].search(message):
            # 标记进入硬件状态解析模式
            self.device_info['status']['hardware_state_mode'] = True
            updated = True
        elif self.device_info['status'].get('hardware_state_mode', False):
            if self.v205_patterns['tfpu_clock_source'].search(message):
                match = self.v205_patterns['tfpu_clock_source'].search(message)
                tfpu_freq = match.group(1).strip()
                self.device_info['system']['tfpu_clock'] = tfpu_freq
                # 更新TFPU状态为已启用
                self.device_info['hardware']['tfpu']['status'] = '已启用'
                # 更新性能信息中的TFPU频率
                self.device_info['performance']['tfpu_frequency'] = tfpu_freq
                self.device_info['performance']['tfpu_enabled'] = True
                updated = True
            elif self.v205_patterns['cpu_clock_source'].search(message):
                match = self.v205_patterns['cpu_clock_source'].search(message)
                cpu_freq = match.group(1).strip()
                self.device_info['system']['cpu_clock'] = cpu_freq
                # 更新性能信息中的CPU频率
                self.device_info['performance']['cpu_frequency'] = cpu_freq
                updated = True
            elif self.v205_patterns['acceleration_ratio'].search(message):
                match = self.v205_patterns['acceleration_ratio'].search(message)
                self.device_info['system']['acceleration_ratio'] = match.group(1).strip()
                updated = True
            elif self.v205_patterns['power_management'].search(message):
                match = self.v205_patterns['power_management'].search(message)
                self.device_info['system']['power_management'] = match.group(1).strip()
                updated = True
            elif '硬件加速测试完成' in message:
                self.device_info['status']['hardware_state_mode'] = False
                updated = True
                self._safe_emit_device_info_update()
            
        if updated:
            # 添加调试信息
            if hasattr(self, 'debug_mode') and self.debug_mode:
                print(f"[DEBUG] 设备信息已更新: {message[:50]}...")
            # 注意：信号已经在parse_system_info中发送，这里避免重复发送
            if '硬件加速测试完成' in message:
                self._safe_emit_device_info_update()
            
        return updated
        
    def send_info_command(self) -> str:
        """生成info命令"""
        return "info"
        
    def get_formatted_device_info(self) -> str:
        """获取格式化的设备信息"""
        info = []
        info.append("=" * 50)
        info.append("AI8051U 设备系统信息")
        info.append("=" * 50)
        info.append("")
        
        # 系统信息
        info.append("【系统信息】")
        
        # 安全访问系统信息
        try:
            if self.device_info['system'].get('mcu'):
                info.append(f"微控制器: {self.device_info['system']['mcu']}")
            
            # 系统名称
            if self.device_info['system'].get('system'):
                info.append(f"系统名称: {self.device_info['system']['system']}")
            
            # 版本信息
            if self.device_info['system'].get('version'):
                info.append(f"版本: {self.device_info['system']['version']}")
            
            # 作者信息
            if self.device_info['system'].get('author'):
                info.append(f"作者: {self.device_info['system']['author']}")
            
            # 时钟频率 - 优先使用clock_frequency，其次使用clock
            clock_freq = self.device_info['system'].get('clock_frequency') or self.device_info['system'].get('clock')
            if clock_freq:
                info.append(f"时钟频率: {clock_freq}")
            
            # Flash大小 - 优先使用flash_size，其次使用flash
            flash_size = self.device_info['system'].get('flash_size') or self.device_info['system'].get('flash')
            if flash_size:
                info.append(f"Flash大小: {flash_size}")
            
            # XRAM大小 - 优先使用xram_size，其次使用xram
            xram_size = self.device_info['system'].get('xram_size') or self.device_info['system'].get('xram')
            if xram_size:
                info.append(f"XRAM大小: {xram_size}")
            
            if self.device_info['system'].get('usb_cdc'):
                info.append(f"USB-CDC: {self.device_info['system']['usb_cdc']}")
            
            if self.device_info['system'].get('build_date'):
                info.append(f"编译日期: {self.device_info['system']['build_date']}")
            
            if self.device_info['system'].get('build_time'):
                info.append(f"编译时间: {self.device_info['system']['build_time']}")
                
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 访问系统信息出错: {e}")
            info.append("系统信息解析出错")
        
        # RTC时钟信息
        if self.device_info['system'].get('rtc_time'):
            info.append("")
            info.append("【RTC时钟】")
            info.append(f"当前时间: {self.device_info['system']['rtc_time']}")
        
        # 内存信息（从memory字段获取）
        info.append("")
        info.append("【内存使用】")
        
        # 调试：检查memory字段内容
        if self.debug_mode:
            print(f"[DEBUG] Memory字段内容: {self.device_info['memory']}")
        
        memory_data_available = False
        
        # 安全访问内存信息
        try:
            if self.device_info['memory'].get('flash_used'):
                info.append(f"Flash已用: {self.device_info['memory']['flash_used']}")
                memory_data_available = True
            if self.device_info['memory'].get('flash_constants'):
                info.append(f"常量存储: {self.device_info['memory']['flash_constants']}")
                memory_data_available = True
            if self.device_info['memory'].get('xram_used'):
                info.append(f"XRAM已用: {self.device_info['memory']['xram_used']}")
                memory_data_available = True
            if self.device_info['memory'].get('internal_ram_used'):
                info.append(f"内部RAM: {self.device_info['memory']['internal_ram_used']}")
                memory_data_available = True
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 访问内存信息出错: {e}")
        
        # 如果内存信息为空，显示提示
        if not memory_data_available:
            info.append("暂无内存使用信息")
        
        # 硬件信息
        if any(self.device_info['hardware']['adc'].values()):
            info.append("")
            info.append("【硬件信息】")
            if self.device_info['hardware']['adc']['resolution']:
                info.append(f"ADC分辨率: {self.device_info['hardware']['adc']['resolution']}")
            if self.device_info['hardware']['adc']['channels']:
                info.append(f"ADC通道数: {self.device_info['hardware']['adc']['channels']}")
            if self.device_info['hardware']['adc']['reference']:
                info.append(f"ADC参考电压: {self.device_info['hardware']['adc']['reference']}")
        
        # 性能信息
        if any(self.device_info['performance'].values()):
            info.append("")
            info.append("【性能信息】")
            if self.device_info['performance']['cpu_frequency']:
                info.append(f"CPU频率: {self.device_info['performance']['cpu_frequency']}")
            if self.device_info['performance']['tfpu_enabled']:
                info.append(f"TFPU状态: {'已启用' if self.device_info['performance']['tfpu_enabled'] else '未启用'}")
            if self.device_info['performance']['tfpu_frequency']:
                info.append(f"TFPU频率: {self.device_info['performance']['tfpu_frequency']}")
            if self.device_info['performance']['benchmark_results']:
                info.append(f"基准测试: {self.device_info['performance']['benchmark_results']}")
        
        # 状态信息
        info.append("")
        info.append("【状态信息】")
        info.append(f"最后更新: {datetime.now().strftime('%Y-%m-%d %H:%M:%S')}")
        
        return "\n".join(info)
        
    def reset(self):
        """重置设备信息管理器"""
        # 简化重置逻辑
        try:
            # 重置系统信息
            for key in self.device_info['system']:
                self.device_info['system'][key] = ''
            
            # 重置硬件信息
            for hw_type in self.device_info['hardware']:
                if isinstance(self.device_info['hardware'][hw_type], dict):
                    for key in self.device_info['hardware'][hw_type]:
                        self.device_info['hardware'][hw_type][key] = ''
            
            # 重置状态
            for key in self.device_info['status']:
                if isinstance(self.device_info['status'][key], bool):
                    self.device_info['status'][key] = False
                else:
                    self.device_info['status'][key] = ''
            
            # 重置性能信息
            if 'performance' in self.device_info and isinstance(self.device_info['performance'], dict):
                for key in self.device_info['performance']:
                    if isinstance(self.device_info['performance'][key], bool):
                        self.device_info['performance'][key] = False
                    else:
                        self.device_info['performance'][key] = ''
            
            # 重置内存信息
            if 'memory' in self.device_info and isinstance(self.device_info['memory'], dict):
                for key in self.device_info['memory']:
                    if isinstance(self.device_info['memory'][key], bool):
                        self.device_info['memory'][key] = False
                    else:
                        self.device_info['memory'][key] = ''
            
            # 重置时钟系统信息
            if 'clock_system' in self.device_info and isinstance(self.device_info['clock_system'], dict):
                for key in self.device_info['clock_system']:
                    self.device_info['clock_system'][key] = ''
            
            # 重置当前测试单元
            if 'current_test_unit' in self.device_info:
                self.device_info['current_test_unit'] = ''
        except Exception as e:
            print(f"[DEBUG] 重置设备信息出错: {e}")
            pass
            self.device_info['performance']['tfpu_sin_ratio'] = ''
            self.device_info['performance']['timing_warnings'] = []
            
            # 重置时钟系统信息
            self.device_info['clock_system']['system_clock'] = ''
            self.device_info['clock_system']['pll_output_clock'] = ''
            self.device_info['clock_system']['high_speed_peripheral_clock'] = ''
            self.device_info['clock_system']['tfpu_clock_divider'] = ''
            self.device_info['clock_system']['prescaler_coefficient'] = ''
            self.device_info['clock_system']['calculated_frequency'] = ''
            self.device_info['clock_system']['cpu_frequency_ratio'] = ''
            self.device_info['clock_system']['clksel_register'] = ''
            self.device_info['clock_system']['usbclk_register'] = ''
            self.device_info['system']['t4t3m_register'] = ''
            self.device_info['clock_system']['dmair_register'] = ''
            self.device_info['clock_system']['tfpu_frequency_verification'] = ''
            self.device_info['clock_system']['conclusion'] = ''
            
            # 重置外设信息
            self.device_info['peripherals'] = {}
            
    def check_mode_timeout(self, current_time):
        """检查模式超时 - 增强版本"""
        for mode in ['system_info_mode', 'hardware_test_mode', 'voltage_mode', 'clock_info_mode']:
            if self.device_info['status'].get(mode, False):
                if mode not in self.mode_start_time:
                    self.mode_start_time[mode] = current_time
                else:
                    # 动态超时时间 - 根据模式类型调整
                    if mode == 'hardware_test_mode':
                        timeout = self.mode_timeout * 2  # 硬件测试需要更长时间
                    elif mode == 'clock_info_mode':
                        timeout = self.mode_timeout * 1.5  # 时钟信息需要中等时间
                    else:
                        timeout = self.mode_timeout  # 默认超时时间
                    
                    # 检查超时
                    if isinstance(current_time, time.struct_time):
                        current_seconds = time.mktime(current_time)
                        start_seconds = time.mktime(self.mode_start_time[mode])
                        elapsed = current_seconds - start_seconds
                    else:
                        elapsed = current_time - self.mode_start_time[mode]
                    
                    if elapsed > timeout:
                        # 超时，退出模式
                        self.device_info['status'][mode] = False
                        del self.mode_start_time[mode]
                        if self.debug_mode:
                            print(f"[DEBUG] {mode} 超时({timeout:.1f}s)，自动退出")
                        self.device_info_updated.emit(self.device_info)
    
    def get_device_info(self) -> dict:
        """获取设备信息字典"""
        return self.device_info
    
    def _safe_access_nested_dict(self, dict_obj, key_path, default_value=''):
        """安全访问嵌套字典"""
        try:
            keys = key_path.split('.')
            current = dict_obj
            for key in keys:
                if isinstance(current, dict) and key in current:
                    current = current[key]
                else:
                    return default_value
            return current if current is not None else default_value
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 访问嵌套字典失败 {key_path}: {e}")
            return default_value
    
    def _check_performance_ratio(self, base_field, ratio_field):
        """检查性能比值是否存在"""
        return (self.device_info['performance'].get(f'{base_field}_avg') and 
                not self.device_info['performance'].get(f'{ratio_field}_ratio'))

    def _calculate_device_info_hash(self):
        """计算设备信息的哈希值，用于检测变化"""
        try:
            # 将设备信息转换为JSON字符串
            info_str = json.dumps(self.device_info, sort_keys=True, separators=(',', ':'))
            # 计算MD5哈希
            return hashlib.md5(info_str.encode()).hexdigest()
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 计算设备信息哈希失败: {e}")
            try:
                # 返回默认哈希值
                return hashlib.md5(b'default').hexdigest()
            except Exception as fallback_e:
                # 如果hashlib完全不可用，返回基于时间的简单哈希
                return f"fallback_{int(time.time())}"
    
    def _generate_content_fingerprint(self, full_hash: str = None) -> str:
        """生成内容指纹，忽略时间戳变化"""
        try:
            # 提取设备信息的核心内容，不包含时间戳
            core_info = {}
            
            # 系统信息
            if 'system' in self.device_info:
                system_info = self.device_info['system'].copy()
                # 移除时间相关字段
                system_info.pop('last_update', None)
                # 移除其他可能的时间戳字段
                time_fields = ['updated_at', 'timestamp', 'last_check']
                for field in time_fields:
                    system_info.pop(field, None)
                core_info['system'] = system_info
            
            # 硬件信息
            if 'hardware' in self.device_info:
                core_info['hardware'] = self.device_info['hardware']
            
            # 性能信息
            if 'performance' in self.device_info:
                core_info['performance'] = self.device_info['performance']
            
            # 内存信息
            if 'memory' in self.device_info:
                core_info['memory'] = self.device_info['memory']
            
            # 状态信息（但移除时间戳相关字段）
            if 'status' in self.device_info:
                status_info = self.device_info['status'].copy()
                status_info.pop('last_update', None)
                for field in ['updated_at', 'timestamp', 'last_check']:
                    status_info.pop(field, None)
                core_info['status'] = status_info
            
            # 生成内容指纹
            content_str = json.dumps(core_info, sort_keys=True, ensure_ascii=False)
            import hashlib
            return hashlib.md5(content_str.encode('utf-8')).hexdigest()[:16]  # 使用MD5并截断
            
        except Exception as e:
            if self.debug_mode:
                print(f"[DEBUG] 生成内容指纹失败: {e}")
            if full_hash:
                return full_hash[:16]  # 返回完整哈希的前16位作为后备
            else:
                return f"fingerprint_{int(time.time())}"  # 返回基于时间的指纹作为后备


#!/usr/bin/env python
"""
ColorBridge 打包配置
正式版本，支持pip安装和跨平台
支持安装后自动配置Windows PATH
"""

import os
import sys
import platform
import subprocess
from setuptools import setup, find_packages
from setuptools.command.install import install
from setuptools.command.develop import develop


class CustomInstallCommand(install):
    """自定义安装命令 - 安装后自动配置PATH"""
    
    def run(self):
        # 调用父类安装
        install.run(self)
        
        # 显示安装成功消息
        print_post_install_message()
        
        # 尝试自动配置PATH
        self._try_configure_path()

    def _try_configure_path(self):
        """尝试自动配置PATH"""
        try:
            # 尝试导入PATH配置模块
            sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))
            from colorbridge._path_config import configure_path_automatically
            
            print("\n🔄 正在尝试自动配置PATH...")
            success, message = configure_path_automatically()
            if success:
                print(f"✅ {message}")
            else:
                print(f"⚠️  {message}")
                print("💡 可以使用以下方式运行:")
                print(f'   python -m colorbridge --version')
                
        except ImportError as e:
            print(f"⚠️  无法导入PATH配置模块: {e}")
            print("💡 请手动运行 add_to_path_windows.bat 或参考安装后消息")
        except Exception as e:
            print(f"⚠️  PATH配置过程中出现错误: {e}")
            print("💡 可以使用以下方式运行:")
            print(f'   python -m colorbridge --version')


class CustomDevelopCommand(develop):
    """自定义开发模式安装命令"""
    
    def run(self):
        # 调用父类安装
        develop.run(self)
        
        # 显示开发模式安装消息
        print("🔧 开发模式安装完成！")
        print("💡 可以使用以下方式运行:")
        print(f'   python -m colorbridge --version')


# 安装后消息函数
def print_post_install_message():
    """安装后显示帮助信息"""
    system = platform.system()
    python_path = sys.executable
    
    print("\n" + "="*60)
    print("🎉 ColorBridge 安装成功！")
    print("="*60)
    
    if system == "Windows":
        print("\n📝 Windows 用户请注意：")
        print("由于Windows安全限制，Python Scripts目录可能不在PATH中。")
        print("\n🔄 推荐解决方案：")
        print("1. 自动配置PATH (最简单):")
        print("   运行: add_to_path_windows.bat (需要管理员权限)")
        print("   或使用: python -m colorbridge._path_config")
        
        print("\n2. 手动运行方式 (无需配置):")
        print(f'   使用: "{python_path}" -m colorbridge --version')
        print(f'   或: "{python_path}" -m colorbridge --help')
        
        print("\n3. 手动配置PATH:")
        print("   a. 右键'此电脑' -> 属性 -> 高级系统设置")
        print("   b. 环境变量 -> 系统变量Path -> 编辑")
        print("   c. 添加: C:\\Users\\%USERNAME%\\AppData\\Roaming\\Python\\Python314\\Scripts")
        print("   d. 重启命令行工具")
    else:
        print(f"\n✅ 安装完成！可以直接使用命令：")
        print("   colorbridge --version")
        print("   colorbridge --help")
    
    print("\n🔧 立即验证安装：")
    print(f'   "{python_path}" -m colorbridge --version')
    
    print("\n📚 完整文档：https://atomgit.com/H076lik/ColorBridge")
    print("💡 提示: 使用'ColorBridge启动器.bat'可获得最佳体验")
    print("="*60 + "\n")

# 读取 README 作为长描述
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# 读取 requirements.txt
with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = [line.strip() for line in fh if line.strip() and not line.startswith("#")]

# 自动发现所有包
packages = find_packages(include=["colorbridge", "colorbridge.*", "core", "ui", "games", "games.billiard_3d"])

# 确保包含colorbridge包
if "colorbridge" not in packages:
    packages.append("colorbridge")

setup(
    name="colorbridge",
    version="2.1.10",
    author="076lik",
    author_email="m17859782086_1@163.com",
    description="🌈 ColorBridge - AI8051U串口助手，半透明多巴胺配色串口调试工具",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://atomgit.com/H076lik/ColorBridge",
    packages=packages,
    include_package_data=True,
    python_requires=">=3.8",
    entry_points={
        "console_scripts": [
            "colorbridge=colorbridge.__main__:main",
        ],
        "gui_scripts": [
            "colorbridge-gui=colorbridge.__main__:main",
        ],
    },
    keywords="serial uart ai8051u usb-cdc debug embedded hardware",
    project_urls={
        "Homepage": "https://atomgit.com/H076lik/ColorBridge",
        "Repository": "https://atomgit.com/H076lik/ColorBridge.git",
        "Issues": "https://atomgit.com/H076lik/ColorBridge/issues",
    },
    # 平台支持
    platforms=["Windows", "Linux", "macOS"],
    # 自定义安装命令
    cmdclass={
        'install': CustomInstallCommand,
        'develop': CustomDevelopCommand,
    },
    # 项目分类
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Embedded Systems",
        "Topic :: Software Development :: User Interfaces",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS :: MacOS X",
    ],
)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
日志保护器模块 - ColorBridge
保护重要日志文件不被误删
"""

import os
import time
import stat
from pathlib import Path
from typing import List, Dict, Any


class LogProtector:
    """日志保护器 - 防止重要日志文件被误删"""
    
    def __init__(self, log_dir: str = None):
        self.log_dir = log_dir or os.path.join(os.path.dirname(__file__), '..', 'logs')
        self.protected_files = set()
        
        # 受保护的文件模式
        self.protected_patterns = [
            'colorbridge_*.log',      # 主日志文件
            'error_*.log',            # 错误日志
            'performance_*.log',      # 性能日志
            'session_*.log',          # 会话日志
            'crash_*.log',            # 崩溃日志
            'debug_*.log'             # 调试日志
        ]
        
        # 保护最近7天的日志
        self.protection_days = 7
        
        # 初始化保护
        self.setup_protection()
    
    def setup_protection(self):
        """设置文件保护"""
        try:
            # 确保日志目录存在
            Path(self.log_dir).mkdir(parents=True, exist_ok=True)
            
            # 查找需要保护的文件
            self.find_protected_files()
            
            # 设置文件属性（在Windows上设置为只读）
            self.set_file_protection()
            
            print(f"[INFO] 日志保护已启用，保护 {len(self.protected_files)} 个文件")
            
        except Exception as e:
            print(f"[ERROR] 日志保护设置失败: {e}")
    
    def find_protected_files(self):
        """查找需要保护的文件"""
        self.protected_files.clear()
        
        try:
            # 获取当前正在使用的日志文件（避免保护当前文件）
            current_log_file = self._get_current_log_file()
            
            for pattern in self.protected_patterns:
                for file_path in Path(self.log_dir).glob(pattern):
                    # 跳过当前正在使用的日志文件
                    if str(file_path) == current_log_file:
                        continue
                    
                    # 检查文件是否在保护期内且不是最近修改的（避免保护活跃文件）
                    if self.is_within_protection_period(file_path) and self._is_inactive_file(file_path):
                        self.protected_files.add(str(file_path))
            
            # 也保护当前运行日志（只读状态）
            current_log = os.path.join(self.log_dir, '运行日志.txt')
            if os.path.exists(current_log):
                self.protected_files.add(current_log)
                
        except Exception as e:
            print(f"[ERROR] 查找保护文件失败: {e}")
    
    def _get_current_log_file(self) -> str:
        """获取当前正在使用的日志文件路径（避免循环依赖）"""
        # 避免循环依赖，不直接调用logger_manager
        # 使用时间戳推断当前日志文件
        try:
            from datetime import datetime
            current_time = datetime.now().strftime("%Y%m%d")
            
            # 查找今天最新的日志文件作为当前文件
            latest_file = ""
            latest_time = 0
            
            for file_path in Path(self.log_dir).glob(f"colorbridge_{current_time}_*.log"):
                try:
                    file_time = file_path.stat().st_mtime
                    if file_time > latest_time:
                        latest_time = file_time
                        latest_file = str(file_path)
                except Exception:
                    continue
            
            return latest_file
        except Exception:
            return ""
    
    def _is_inactive_file(self, file_path: Path) -> bool:
        """检查文件是否为非活跃文件（超过10分钟未修改）"""
        try:
            file_stat = file_path.stat()
            file_time = file_stat.st_mtime
            current_time = time.time()
            
            # 超过10分钟未修改的文件被认为是非活跃的
            inactive_cutoff = current_time - (10 * 60)  # 10分钟
            return file_time < inactive_cutoff
            
        except Exception:
            return True  # 如果无法确定，默认为非活跃
    
    def is_within_protection_period(self, file_path: Path) -> bool:
        """检查文件是否在保护期内"""
        try:
            file_stat = file_path.stat()
            file_time = file_stat.st_mtime
            current_time = time.time()
            
            # 保护期内的文件
            protection_cutoff = current_time - (self.protection_days * 24 * 3600)
            return file_time >= protection_cutoff
            
        except Exception:
            return False
    
    def set_file_protection(self):
        """设置文件保护属性"""
        try:
            for file_path in self.protected_files:
                if os.path.exists(file_path):
                    # Windows: 设置为只读
                    if os.name == 'nt':
                        # 使用基础的读写权限保护，不依赖win32api
                        try:
                            # 移除写权限，设置为只读
                            current_mode = os.stat(file_path).st_mode
                            # 保留读取权限，移除写权限
                            new_mode = current_mode & ~stat.S_IWUSR & ~stat.S_IWGRP & ~stat.S_IWOTH
                            os.chmod(file_path, new_mode)
                        except Exception as e:
                            print(f"[ERROR] 设置文件权限失败: {e}")
                    else:
                        # Unix/Linux: 移除写权限
                        current_mode = os.stat(file_path).st_mode
                        os.chmod(file_path, current_mode & ~stat.S_IWUSR & ~stat.S_IWGRP & ~stat.S_IWOTH)
                        
        except Exception as e:
            print(f"[ERROR] 设置文件保护失败: {e}")
    
    def remove_protection(self, file_path: str = None):
        """移除文件保护"""
        try:
            if file_path:
                files_to_unprotect = [file_path]
            else:
                files_to_unprotect = list(self.protected_files)
            
            for file_path in files_to_unprotect:
                if os.path.exists(file_path):
                    # Windows: 移除只读属性
                    if os.name == 'nt':
                        # 使用基础的读写权限恢复，不依赖win32api
                        try:
                            # 恢复写权限
                            current_mode = os.stat(file_path).st_mode
                            # 恢复读写权限
                            new_mode = current_mode | stat.S_IWUSR | stat.S_IWGRP | stat.S_IWOTH
                            os.chmod(file_path, new_mode)
                        except Exception as e:
                            print(f"[ERROR] 恢复文件权限失败: {e}")
            
            if file_path in self.protected_files:
                self.protected_files.remove(file_path)
                
        except Exception as e:
            print(f"[ERROR] 移除文件保护失败: {e}")
    
    def is_protected(self, file_path: str) -> bool:
        """检查文件是否受保护"""
        return file_path in self.protected_files
    
    def cleanup_old_logs(self, force: bool = False):
        """清理旧日志文件"""
        try:
            cutoff_time = time.time() - (self.protection_days * 24 * 3600)
            cleaned_count = 0
            protected_count = 0
            
            for file_path in Path(self.log_dir).glob("*.log"):
                if file_path.stat().st_mtime < cutoff_time:
                    if str(file_path) in self.protected_files and not force:
                        protected_count += 1
                        continue
                    
                    try:
                        file_path.unlink()
                        cleaned_count += 1
                    except Exception as e:
                        print(f"[ERROR] 删除日志文件失败 {file_path}: {e}")
            
            print(f"[INFO] 清理完成: 删除 {cleaned_count} 个文件，保护 {protected_count} 个文件")
            return cleaned_count
            
        except Exception as e:
            print(f"[ERROR] 清理旧日志失败: {e}")
            return 0
    
    def get_protection_status(self) -> Dict[str, Any]:
        """获取保护状态"""
        try:
            total_size = 0
            file_details = []
            
            for file_path in self.protected_files:
                if os.path.exists(file_path):
                    stat = os.stat(file_path)
                    total_size += stat.st_size
                    file_details.append({
                        'path': file_path,
                        'size': stat.st_size,
                        'modified': stat.st_mtime
                    })
            
            return {
                'protected_count': len(self.protected_files),
                'total_size': total_size,
                'protection_days': self.protection_days,
                'files': file_details
            }
            
        except Exception as e:
            return {'error': str(e)}
    
    def add_protection(self, file_path: str):
        """添加文件保护"""
        if os.path.exists(file_path):
            self.protected_files.add(file_path)
            self.set_file_protection()


# 全局日志保护器实例
_log_protector = None

def get_log_protector() -> LogProtector:
    """获取全局日志保护器实例"""
    global _log_protector
    if _log_protector is None:
        _log_protector = LogProtector()
    return _log_protector

def init_log_protector(log_dir: str = None) -> LogProtector:
    """初始化全局日志保护器"""
    global _log_protector
    _log_protector = LogProtector(log_dir=log_dir)
    return _log_protector